<?php
/**
 * All Elementor widget init
 * @package innomax
 * @since 1.0.0
 */

if ( !defined('ABSPATH') ){
	exit(); // exit if access directly
}

if ( !class_exists('Innomax_Elementor_Widget_Init') ){

	class Innomax_Elementor_Widget_Init{
		/*
		* $instance
		* @since 1.0.0
		* */
		private static $instance;
		/*
		* construct()
		* @since 1.0.0
		* */
		public function __construct() {
			add_action( 'elementor/elements/categories_registered', array($this,'_widget_categories') );
			//elementor widget registered
			add_action('elementor/widgets/register',array($this,'_widget_registered'));
			add_action('elementor/editor/after_enqueue_styles',array($this,'editor_style'));
			add_action('elementor/documents/register_controls',array($this,'register_document_controls'));
		}
		/*
	   * getInstance()
	   * @since 1.0.0
	   * */
		public static function getInstance(){
			if ( null == self::$instance ){
				self::$instance = new self();
			}
			return self::$instance;
		}
		/**
		 * _widget_categories()
		 * @since 1.0.0
		 * */
		public function _widget_categories($elements_manager){
			$elements_manager->add_category(
				'innomax_widgets',
				[
					'title' => __( 'Innomax Addons', 'innomax-core' ),
					'icon' => 'fa fa-plug'
				]
			);
			$elements_manager->add_category(
				'innomax_hf_widgets',
				[
					'title' => __( 'Innomax Header & Footer', 'innomax-core' ),
					'icon' => 'fa fa-plug'
				]
			);
		}
		

		/**
		 * _widget_registered()
		 * @since 1.0.0
		 * */
		public function _widget_registered(){
			if( !class_exists('Elementor\Widget_Base') ){
				return;
			}
			$elementor_widgets = array(	
				
				// innomax Theme Widgets
				'sec-title',
				'xb-button',
				'xb-heading',
				'hero-one',
				'hero-two',
				'hero-three',
				'hero-four',
				'hero-five',
				'hero-six',
				'brand',
				'brand-v2',
				'brand-v3',
				'brand-v4',
				'brand-v5',
				'brand-v6',
				'brand-v7',
				'about',
				'about-v2',
				'about-v3',
				'about-v4',
				'service',
				'casestudy',
				'casestudy-v2',
				'casestudy-v3',
				'casestudy-v4',
				'casestudy-title',
				'process',
				'process-v2',
				'process-v3',
				'process-v4',
				'process-v5',
				'process-v6',
				'industrie',
				'industrie-v2',
				'testimonial',
				'testimonial-v2',
				'testimonial-v3',
				'testimonial-v4',
				'testimonial-v5',
				'features',
				'features-v2',
				'features-v3',
				'features-v4',
				'features-v5',
				'features-v6',
				'features-v7',
				'features-v8',
				'team',
				'team-v2',
				'team-v3',
				'team-info',
				'faq',
				'faq-v2',
				'faq-v3',
				'faq-v4',
				'cta',
				'cta-v2',
				'cta-v3',
				'cta-v4',
				'cta-v5',
				'footer-info',
				'footer-info-v2',
				'footer-links',
				'footer-links-v2',
				'footer-links-v3',
				'xb-social',
				'service-v2',
				'service-v3',
				'service-v4',
				'service-v5',
				'service-v6',
				'funfact',
				'funfact-v2',
				'funfact-v3',
				'funfact-v4',
				'funfact-v5',
				'parallax-image',
				'contact',
				'contact-v2',
				'contact-v3',
				'contact-info',
				'contact-info-v2',
				'newsletter',
				'newsletter-v2',
				'footer-nav',
				'footer-marquee',
				'footer-marquee-v2',
				'footer-marquee-v3',
				'blog',
				'blog-v2',
				'blog-v3',
				'blog-v4',
				'blog-v5',
				'award',
				'award-title',
				'xb-video',
				'xb-video-v2',
				'xb-video-v3',
				'xb-video-v4',
				'xb-video-v5',
				'feature-image',
				'integration',
				'integration-title',
				'award-v2',
				'award-v3',
				'casestudy-info',
				'page-title',
				'page-title-v2',
				'page-title-v3',
				'page-title-v4',
				'page-title-v5',
				'roadmap',
				'pricing',
				'pricing-tab',
				'career',
				'career-form',
				'megamenu-company',
				'megamenu-service',

				// header
				'01-header',
				'02-header',
				'03-header',
				'04-header',
				'05-header',
				'06-header',

				// header
				'01-footer',
				'02-footer',

			);

			$elementor_widgets = apply_filters('innomax_elementor_widget',$elementor_widgets);

			if ( is_array($elementor_widgets) && !empty($elementor_widgets) ) {
				foreach ( $elementor_widgets as $widget ){
					$widget_file = 'plugins/elementor/widget/'.$widget.'.php';
					$template_file = locate_template($widget_file);
					if ( !$template_file || !is_readable( $template_file ) ) {
						$template_file = INNOMAX_DIR_PATH.'/elementor/widgets/'.$widget.'.php';
					}
					if ( $template_file && is_readable( $template_file ) ) {
						include_once $template_file;
					}
				}
			}
		}

		public function editor_style(){
			$cs_icon = plugins_url( 'icons.png', __FILE__ );
			wp_add_inline_style( 'elementor-editor', '.elementor-element .icon .innomax-custom-icon{content: url( '.$cs_icon.');width: 28px;}' );
		}

		/**
		 * Register additional document controls.
		 *
		 * @param \Elementor\Core\DocumentTypes\PageBase $document The PageBase document instance.
		 */
		public function register_document_controls( $document ) {

			if ( ! $document instanceof \Elementor\Core\DocumentTypes\PageBase || ! $document::get_property( 'has_elements' ) ) {
				return;
			}

			$document->start_controls_section(
				'body_typography',
				[
					'label' => esc_html__( 'Body Typography', 'innomax-core' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$document->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'page_body_font',
					'selector' => '{{WRAPPER}}',
				]
			);
			$document->add_control(
				'body_color',
				[
					'label' => esc_html__( 'Body Color', 'innomax-core' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}}' => 'color: {{VALUE}}',
					],
				]
			);
			$document->add_control(
				'heading_color',
				[
					'label' => esc_html__( 'Heading Color', 'innomax-core' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} h1, h2, h3, h4, h5, h6' => 'color: {{VALUE}}',
					],
				]
			);
			$document->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'page_heading_font',
					'selector' => '{{WRAPPER}} h1, {{WRAPPER}} h2, {{WRAPPER}} h3, {{WRAPPER}} h4, {{WRAPPER}} h5, {{WRAPPER}} h6',
				]
			);

			$document->end_controls_section();
		}
	}

	if ( class_exists('Innomax_Elementor_Widget_Init') ){
		Innomax_Elementor_Widget_Init::getInstance();
	}

}//end if