<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Footer extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'innomax-footer';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Footer', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_hf_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'logoop',
            [
                'label' => esc_html__('Logo Option', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'logo', [
                'label' => esc_html__('Logo', 'innomax-core'),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'logo_badge',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Logo Badge', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'logolink',
            [
                'label' => esc_html__('Logo Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_responsive_control(
            'logo_max_width',
            [
                'label' => esc_html__('Max Width', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 5000,
                    ]
                ],

                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--logo img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'navigation_option',
            [
                'label' => esc_html__('Navigation', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Nav Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'navs',
            [
                'label' => esc_html__('Add Navigation', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ label }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'links_option',
            [
                'label' => esc_html__('Copyright & Links', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'copyright_text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Copyright Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Link Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'links',
            [
                'label' => esc_html__('Add Link', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ label }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .xb-footer' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .xb-footer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'logo_badge_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'logo_badge-c',
            [
                'label' => esc_html__('Logo Badge Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'logo_badge_bg-c',
            [
                'label' => esc_html__('Logo Badge BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--content' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'logo_badge_typography',
                'selector' => '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--content',
            ]
        );
        $this->add_control(
            'nav_style_hr',
            [
                'label' => esc_html__('Navigation Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--nav_item li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hnav-c',
            [
                'label' => esc_html__('Nav Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--nav_item li a:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .footer-style-six .da-footer-inner .xb-item--nav_item li::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'bottom_border_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'bottom_border-c',
            [
                'label' => esc_html__('Bottom Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .footer-copyright' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'copyright_text_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'copyright_text_c',
            [
                'label' => esc_html__('Copyright Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .footer-copyright .copyright' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .footer-style-six .footer-copyright .copyright a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'copyright_text_typography',
                'selector' => '{{WRAPPER}} .footer-style-six .footer-copyright .copyright',
            ]
        );
        $this->add_control(
            'links_style_hr',
            [
                'label' => esc_html__('Links Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'link-c',
            [
                'label' => esc_html__('Link Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .footer-links li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_hover-c',
            [
                'label' => esc_html__('Link Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-six .footer-links li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'selector' => '{{WRAPPER}} .footer-style-six .footer-links li a',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="footer-style-six">
            <div class="xb-footer">
                <div class="da-footer-inner ul_li_between mt-none-30">
                    <div class="xb-item--left mt-10">
                        <?php if (!empty($settings['logo']['url'])): ?>
                            <div class="xb-item--logo mt-20">
                                <a href="<?php if (!empty($settings['logolink']['url'])) {
                                    echo esc_url($settings['logolink']['url']);
                                } else {
                                    echo esc_url(home_url('/'));
                                } ?>"><img src="<?php echo esc_url($settings['logo']['url']); ?>"
                                           alt=""></a>
                            </div>
                        <?php endif; ?>
                        <?php if (!empty($settings['logo_badge'])): ?>
                            <span class="xb-item--content mt-20"><?php echo esc_html($settings['logo_badge']); ?></span>
                        <?php endif; ?>
                    </div>
                    <ul class="xb-item--nav_item mt-30 list-unstyled ul_li">
                        <?php
                        foreach ($settings['navs'] as $nav):
                            ?>
                            <li>
                                <a href="<?php echo esc_url($nav['link']['url']); ?>"><?php echo esc_html($nav['label']); ?></a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
                <div class="footer-copyright mt-40 ul_li_between">
                    <?php if (!empty($settings['copyright_text'])): ?>
                        <p class="copyright"><?php echo wp_kses($settings['copyright_text'], true); ?></p>
                    <?php endif; ?>
                    <ul class="footer-links ul_li">
                        <?php
                        foreach ($settings['links'] as $link):
                            ?>
                            <li>
                                <a href="<?php echo esc_url($link['link']['url']); ?>"><?php echo esc_html($link['label']); ?></a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>
        </div>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Innomax_Footer());