<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Footer_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'innomax-footer-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Footer V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_hf_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'widget_one_option',
            [
                'label' => esc_html__('Widget One', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title1',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Nav Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'navs',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ label }}}',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'widget_two_option',
            [
                'label' => esc_html__('Widget Two', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'info',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Info Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'infos',
            [
                'label' => esc_html__('Add Info', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ info }}}',
            ]
        );

        $this->add_control(
            'social_hr',
            [
                'label' => esc_html__('Social', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'socials',
            [
                'label' => esc_html__('Add Social', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'widget_three_option',
            [
                'label' => esc_html__('Widget Three', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title3',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'app_image',
            [
                'label' => esc_html__('App Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'app_link',
            [
                'label' => esc_html__('App Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'apps',
            [
                'label' => esc_html__('Add App Image', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->add_control(
            'newsletter_form_hr',
            [
                'label' => esc_html__('Newsletter', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'title4',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'shortcode',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Shortcode', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'links_option',
            [
                'label' => esc_html__('Copyright & Links', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'copyright_text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Copyright Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Link Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'links',
            [
                'label' => esc_html__('Add Link', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ label }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'border-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-nees-helf::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .footer-style-four .sa-newslatter::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .footer-style-four .footer-copyright' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--sub-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--input-box .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--sub-title, {{WRAPPER}} .footer-style-four .footer-widget .xb-item--input-box .title',
            ]
        );
        $this->add_control(
            'nav_link_style_hr',
            [
                'label' => esc_html__('Navigation Link Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .xb-item--nav li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_hover-c',
            [
                'label' => esc_html__('Nav Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .xb-item--nav li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nav_typography',
                'selector' => '{{WRAPPER}} .footer-style-four .xb-item--nav li a',
            ]
        );
        $this->add_control(
            'info_style_hr',
            [
                'label' => esc_html__('Info Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'info-c',
            [
                'label' => esc_html__('Info Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'info_icon-c',
            [
                'label' => esc_html__('Info Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--number span svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'info_typography',
                'selector' => '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--number',
            ]
        );
        $this->add_control(
            'social_style_hr',
            [
                'label' => esc_html__('Social Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'social-c',
            [
                'label' => esc_html__('Social Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--social-icon a svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'social_bg-c',
            [
                'label' => esc_html__('Social BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--social-icon a' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hsocial_bg-c',
            [
                'label' => esc_html__('Social Hover BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--social-icon:hover a' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'social_border-c',
            [
                'label' => esc_html__('Social Hover Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--social-icon a' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hsocial_border-c',
            [
                'label' => esc_html__('Social Hover Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-style-four .footer-widget .xb-item--social-icon:hover a' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'copyright_style_hr',
            [
                'label' => esc_html__('Copyright Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'copyright-c',
            [
                'label' => esc_html__('Copyright Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-copyright .copyright' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'copyright_link-c',
            [
                'label' => esc_html__('Copyright Link Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-copyright .copyright a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'copyright_typography',
                'selector' => '{{WRAPPER}} .footer-copyright .copyright',
            ]
        );
        $this->add_control(
            'link_style_hr',
            [
                'label' => esc_html__('Link Style Info', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <footer class="footer footer-style-two footer-style-four pos-rel">
            <div class="container">
                <div class="xb-footer">
                    <div class="row">
                        <div class="col-lg-4 col-md-6">
                            <div class="footer-widget">
                                <?php if (!empty($settings['title1'])): ?>
                                    <span class="xb-item--sub-title"><?php echo wp_kses($settings['title1'], true); ?></span>
                                <?php endif; ?>
                                <ul class="xb-item--nav list-unstyled">
                                    <?php
                                    foreach ($settings['navs'] as $nav):
                                        ?>
                                        <li class="xb-item--list"><a href="<?php echo esc_html($nav['link']['url']); ?>"><?php echo esc_html($nav['label']); ?></a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-4 col-md-6">
                            <div class="footer-widget footer-nees-helf">
                                <?php if (!empty($settings['title2'])): ?>
                                    <span class="xb-item--sub-title"><?php echo wp_kses($settings['title2'], true); ?></span>
                                <?php endif; ?>
                                <ul class="xb-item--holder list-unstyled">
                                    <?php
                                    foreach ($settings['infos'] as $info):
                                        ?>
                                        <li class="xb-item--number">
                                            <span><?php \Elementor\Icons_Manager::render_icon($info['icon'], ['aria-hidden' => 'true']); ?></span>
                                            <?php echo esc_html($info['info']); ?>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                                <ul class="xb-item--social-link list-unstyled ul_li mt-45">
                                    <?php
                                    foreach ($settings['socials'] as $social):
                                        ?>
                                        <li class="xb-item--social-icon"><a
                                                    href="<?php echo esc_url($social['link']['url']); ?>"><?php \Elementor\Icons_Manager::render_icon($social['icon'], ['aria-hidden' => 'true']); ?></a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-4 col-md-6">
                            <div class="sa-newslatter footer-widget">
                                <?php if (!empty($settings['title3'])): ?>
                                    <span class="xb-item--sub-title"><?php echo wp_kses($settings['title3'], true); ?></span>
                                <?php endif; ?>
                                <div class="xb-item--apps ul_li">
                                    <?php
                                    foreach ($settings['apps'] as $app):
                                        ?>
                                        <div class="xb-item--app">
                                            <a href="<?php echo esc_url($app['app_link']['url']); ?>"><?php echo wp_get_attachment_image($app['app_image']['id'], 'medium'); ?></a>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                <div class="xb-item--input-box">
                                    <?php if (!empty($settings['title4'])): ?>
                                        <span class="title"><?php echo wp_kses($settings['title4'], true); ?></span>
                                    <?php endif; ?>
                                    <?php if (!empty($settings['shortcode'])): ?>
                                        <div class="innomax-newslatter xb-item--input_field pos-rel">
                                            <?php echo do_shortcode($settings['shortcode']); ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="footer-copyright ul_li_between">
                        <?php if (!empty($settings['copyright_text'])): ?>
                            <p class="copyright mt-20"><?php echo wp_kses($settings['copyright_text'], true); ?></p>
                        <?php endif; ?>
                        <ul class="hds-footer-links ul_li mt-20">
                            <?php
                            foreach ($settings['links'] as $link):
                                ?>
                                <li>
                                    <a href="<?php echo esc_url($link['link']['url']); ?>"><?php echo esc_html($link['label']); ?></a>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Innomax_Footer_V2());