<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_About_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-about-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('About V4', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'sub_title_icon',
            [
                'label' => esc_html__('Sub Title Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content', [
                'label' => esc_html__('Content', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_option_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'right_content_option',
            [
                'label' => esc_html__('Right Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'r_content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape2',
            [
                'label' => esc_html__('Shape Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'subtitle_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sec-title--three .sub-title span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'sub_title_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title',
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--three .title',
            ]
        );
        $this->add_control(
            'title_padding',
            [
                'label' => esc_html__('Title Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' => esc_html__('Title Margin', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'content_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .sec-title--three .content',
            ]
        );
        $this->add_control(
            'btn_style_hr',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .blc-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .blc-btn',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'content_style_option',
            [
                'label' => esc_html__('Right Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'r_number_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-about_right .xb-content .xb-item--number',
                'fields_options' => [
                    'background' => [
                        'label' => 'Number Color'
                    ],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'r_number_typography',
                'selector' => '{{WRAPPER}} .cs-about_right .xb-content .xb-item--number',
            ]
        );
        $this->add_control(
            'r_content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-about_right .xb-content .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'r_content_typography',
                'selector' => '{{WRAPPER}} .cs-about_right .xb-content .xb-item--content',
            ]
        );

        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="cs-about-wrap pos-rel">
            <div class="row mt-none-60">
                <div class="col-lg-6 mt-60">
                    <div class="cs-about_left">
                        <div class="sec-title--two sec-title--three">
                            <?php if (!empty($settings['sub_title'])): ?>
                                <span class="sub-title wow fadeInUp"
                                      data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><span><?php echo esc_html($settings['sub_title']); ?></span></span>
                            <?php endif; ?>
                            <?php if (!empty($settings['title'])): ?>
                                <h2 class="title wow skewIn" data-wow-delay="150ms"
                                    data-wow-duration="600ms"><?php echo wp_kses($settings['title'], true); ?></h2>
                            <?php endif; ?>
                            <?php if (!empty($settings['content'])): ?>
                                <p class="content wow fadeInUp" data-wow-delay="300ms"
                                   data-wow-duration="600ms"><?php echo esc_html($settings['content'], true); ?></p>
                            <?php endif; ?>
                        </div>
                        <?php if (!empty($settings['btn_label'])): ?>
                            <div class="xb-btn mt-85 wow fadeInUp" data-wow-delay="450ms" data-wow-duration="600ms">
                                <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="blc-btn">
                                    <span><?php echo esc_html($settings['btn_label']); ?> <i
                                                class="far fa-angle-right"></i></span>
                                    <span class="btn-shape">
                                            <svg width="271" height="60" viewBox="0 0 271 60" fill="none"
                                                 preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0.5 17.2308L20.1225 0.5H252.042L270.5 17.2217V43.7692L252.05 59.5H20.1225L0.5 42.7692V17.2308Z"
                                                      fill="#010315" stroke="url(#paint0_linear_1742_66189)"/>
                                                <defs>
                                                  <linearGradient id="paint0_linear_1742_66189" x1="271" y1="61.5556"
                                                                  x2="232.791" y2="-3.08978"
                                                                  gradientUnits="userSpaceOnUse">
                                                    <stop offset="0" stop-color="#6780D2"/>
                                                    <stop offset="1" stop-color="#2F3B8D"/>
                                                  </linearGradient>
                                                </defs>
                                              </svg>
                                        </span>
                                    <span class="btn-shape2">
                                            <svg width="362" height="78" viewBox="0 0 362 78" fill="none"
                                                 preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0.5 22.7183L25.5093 1.39453H337.972L361.5 22.7092V56.5515L337.98 76.6051H25.5093L0.5 55.2813V22.7183Z"
                                                      fill="url(#paint0_linear_1600_9966989)" stroke="#23263C"/>
                                                <defs>
                                                  <linearGradient id="paint0_linear_1600_9966989" x1="1.29285"
                                                                  y1="38.9973" x2="362" y2="33.9973"
                                                                  gradientUnits="userSpaceOnUse">
                                                    <stop offset="0" stop-color="#431DAB"/>
                                                    <stop offset="1" stop-color="#AE6DFE"/>
                                                  </linearGradient>
                                                </defs>
                                              </svg>
                                        </span>
                                </a>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="col-lg-6 mt-60">
                    <div class="cs-about_right wow fadeInRight" data-wow-duration="600ms">
                        <?php if (!empty($settings['image']['id'])): ?>
                            <div class="xb-img">
                                <?php echo wp_get_attachment_image($settings['image']['id'], 'full'); ?>
                            </div>
                        <?php endif; ?>
                        <div class="xb-content">
                            <?php if (!empty($settings['shape']['id'])): ?>
                                <div class="xb-item--img">
                                    <?php echo wp_get_attachment_image($settings['shape']['id'], 'full'); ?>
                                </div>
                            <?php endif; ?>
                            <div class="xb-item--inner">
                                <?php if (!empty($settings['number'])): ?>
                                    <h3 class="xb-item--number"><?php echo esc_html($settings['number']); ?></h3>
                                <?php endif; ?>
                                <?php if (!empty($settings['r_content'])): ?>
                                    <p class="xb-item--content"><?php echo esc_html($settings['r_content']); ?></p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php if (!empty($settings['shape2']['id'])): ?>
                <div class="xb-shape">
                    <?php echo wp_get_attachment_image($settings['shape2']['id'], 'full'); ?>
                </div>
            <?php endif; ?>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_About_V4());