<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Blog_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-blog-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Blog V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'post_option',
            [
                'label' => esc_html__('Post Option', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label' => esc_html__('Post Order', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC' => esc_html__('Ascending', 'innomax-core'),
                    'DESC' => esc_html__('Descending', 'innomax-core'),
                ],
            ]
        );
        $this->add_control(
            'post_per_page',
            [
                'label' => __('Posts Per Page', 'innomax-core'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 3,
            ]
        );
        $this->add_control(
            'post_categories',
            [
                'type' => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Categories', 'innomax-core'),
                'options' => innomax_blog_category(),
                'label_block' => true,
                'multiple' => true,
            ]
        );
        $this->add_control(
            'title_length',
            [
                'label' => __('Title Length', 'innomax-core'),
                'type' => Controls_Manager::NUMBER,
                'step' => 1,
                'default' => 8,
            ]
        );
        $this->add_control(
            'button_label', [
                'label' => esc_html__('Readmore Button', 'innomax-core'),
                'default' => esc_html__('Read More', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'post_style',
            [
                'label' => esc_html__('Post Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'hover_icon_bg_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .xb-blog-item .xb-item--circle-arrow',
                'fields_options' => [
                    'background' => [
                        'label' => 'Hover Icon BG Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-blog-item .xb-item--title',
            ]
        );
        $this->add_control(
            'meta_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'meta-c',
            [
                'label' => esc_html__('Meta Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog-item .xb-item--meta li' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typography',
                'selector' => '{{WRAPPER}} .xb-blog-item .xb-item--meta li',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $arrow = INNOMAX_DIR_URL . 'assets/img/arrow-white.png';
        $line = INNOMAX_DIR_URL . 'assets/img/blg-line.png';
        $user = INNOMAX_DIR_URL . 'assets/img/profile-circle.png';
        $calendar = INNOMAX_DIR_URL . 'assets/img/menu-board.png';
        $args = array(
            'post_type' => 'post',
            'posts_per_page' => !empty($settings['post_per_page']) ? $settings['post_per_page'] : 1,
            'post_status' => 'publish',
            'ignore_sticky_posts' => 1,
            'order' => $settings['post_order'],
        );
        if (!empty($settings['post_categories'])) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }

        $query = new \WP_Query($args);
        ?>

        <div class="cs-blog-wrapper">
            <div class="row mt-none-40">
                <?php
                $delay = 0;
                if ($query->have_posts()) {
                    while ($query->have_posts()) {
                        $query->the_post();
                        ?>
                        <div class="col-lg-4 col-md-6 mt-30">
                            <div class="xb-blog-item wow fadeInUp" data-wow-delay="<?php echo $delay; ?>ms"
                                 data-wow-duration="600ms">
                                <?php if (has_post_thumbnail()): ?>
                                    <div class="xb-item--holder">
                                        <a href="<?php the_permalink(); ?>" class="xb-item--img">
                                            <?php the_post_thumbnail('innomax-blog-2'); ?>
                                            <div class="xb-item--circle-arrow"><img src="<?php echo $arrow; ?>" alt="">
                                            </div>
                                            <div class="xb-item--line"><img src="<?php echo $line; ?>" alt=""></div>
                                        </a>
                                    </div>
                                <?php endif; ?>
                                <h2 class="xb-item--title border-effect"><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['title_length'], ''); ?></a>
                                </h2>
                                <ul class="xb-item--meta list-unstyled ul_li">
                                    <li><span><img src="<?php echo $user; ?>" alt=""></span><?php _e('Posted By'); ?>
                                        <?php the_author(); ?>
                                    </li>
                                    <li><span><img src="<?php echo $calendar; ?>" alt=""></span><?php echo get_the_date('m/d/Y'); ?></li>
                                </ul>
                            </div>
                        </div>
                        <?php
                        $delay += 150;
                    }
                    wp_reset_query();
                } ?>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Blog_V2());