<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Brand_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-brand-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Brand V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'left_icon',
            [
                'label' => esc_html__('Title Left Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'right_icon',
            [
                'label' => esc_html__('Title Right Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'brand_list_hr',
            [
                'label' => esc_html__('Add Brand', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'big_item',
            [
                'label' => esc_html__('One Item', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $repeater->add_control(
            'logo1',
            [
                'label' => esc_html__('Logo One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'link1',
            [
                'label' => esc_html__('Link One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'condition' => [
                    'big_item!' => 'yes'
                ],
            ]
        );
        $repeater->add_control(
            'logo2',
            [
                'label' => esc_html__('Logo Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'big_item!' => 'yes'
                ],
            ]
        );
        $repeater->add_control(
            'link2',
            [
                'label' => esc_html__('Link Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'label_block' => true,
                'condition' => [
                    'big_item!' => 'yes'
                ],
            ]
        );
        $this->add_control(
            'brands',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-brand-title span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-brand-title span',
            ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' => esc_html__('Title Margin', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-brand-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_border_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'brand-border-c',
            [
                'label' => esc_html__('Brand Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-brand-single' => 'border-color: {{VALUE}} !important',
                    '{{WRAPPER}} .xb-brand-wrap' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .xb-brand-item--big' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="brand-two">
            <?php if (!empty($settings['title'])): ?>
                <div class="xb-brand-title mb-65">
                    <?php \Elementor\Icons_Manager::render_icon($settings['left_icon'], ['aria-hidden' => 'true']); ?>
                    <span><?php echo esc_html($settings['title']); ?></span>
                    <?php \Elementor\Icons_Manager::render_icon($settings['right_icon'], ['aria-hidden' => 'true']); ?>
                </div>
            <?php endif; ?>
            <div class="xb-brand-wrap">
                <?php
                foreach ($settings['brands'] as $brand):
                    ?>
                    <div class="xb-brand-item <?php if ('yes' == $brand['big_item']) {
                        echo esc_attr('xb-brand-item--big');
                    } ?>">
                        <?php if (!empty($brand['logo1']['id'])): ?>
                            <div class="xb-brand-single xb-brand-hover">
                                <a href="<?php echo esc_url($brand['link1']['url']); ?>">
                                    <?php echo wp_get_attachment_image($brand['logo1']['id'], 'medium'); ?>
                                </a>
                                <a href="<?php echo esc_url($brand['link1']['url']); ?>" class="xb-overlay"></a>
                            </div>
                        <?php endif; ?>
                        <?php if (!empty($brand['logo1']['id']) && $brand['big_item'] != 'yes'): ?>
                            <div class="xb-brand-single xb-brand-hover">
                                <?php if (!empty($brand['logo2']['id'])) ?>
                                <a href="<?php echo esc_url($brand['link2']['url']); ?>">
                                    <?php echo wp_get_attachment_image($brand['logo2']['id'], 'medium'); ?>
                                </a>
                                <a href="<?php echo esc_url($brand['link2']['url']); ?>" class="xb-overlay"></a>
                            </div>
                        <?php endif; ?>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Brand_V2());