<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Brand_V5 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-brand-v5';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Brand V5', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'brand_top',
            [
                'label' => esc_html__('Brand Top', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'brandstop',
            [
                'label' => esc_html__('Add Brand', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->add_control(
            'brand_bottom',
            [
                'label' => esc_html__('Brand Bottom', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'brandsbottom',
            [
                'label' => esc_html__('Add Brand', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'label' => esc_html__('Content', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'title_top',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title Top', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_middle',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title Middle', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_bottom',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title Bottom', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'sub_title_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-brand_content .sub-title--inner span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'subtitle_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-brand_content .sub-title--inner' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .cs-brand_content .sub-title--inner span',
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-brand_content .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'title_mark_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-brand_content .sub-title--inner span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Title Mark Color'
                    ],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .cs-brand_content .title span',
            ]
        );
        $this->add_control(
            'brand_logo_hr',
            [
                'label' => esc_html__('Brand Logo Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'brand_logo_border_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-brand-item',
                'fields_options' => [
                    'background' => [
                        'label' => 'Brand Logo Border Color'
                    ],
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="cs-brand_wrap pt-60 pb-60 pos-rel">
            <div class="cs-brand-inner marquee-left">
                <?php
                foreach ($settings['brandstop'] as $brand):
                    ?>
                    <div class="cs-brand-item">
                        <div class="xb-inner">
                            <div class="xb-img">
                                <?php echo wp_get_attachment_image($brand['logo']['id'], 'medium'); ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
            <div class="clearfix"></div>
            <div class="cs-brand-inner marquee-right">
                <?php
                foreach ($settings['brandsbottom'] as $brand):
                    ?>
                    <div class="cs-brand-item">
                        <div class="xb-inner">
                            <div class="xb-img">
                                <?php echo wp_get_attachment_image($brand['logo']['id'], 'medium'); ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
            <div class="cs-brand_content">
                <div class="xb-holder">
                    <?php if (!empty($settings['title_top'])): ?>
                        <span class="sub-title">
                            <span data-parallax='{"x":50,"y":70}'>
                                <span class="sub-title--inner"><span>Effective service</span></span>
                                <svg width="19" height="18" viewBox="0 0 19 18" fill="none"
                                     xmlns="http://www.w3.org/2000/svg">
                                    <path d="M18.4871 16.9645C18.7081 17.5684 18.1337 18.1603 17.5235 17.9576L1.04049 12.4812C0.386752 12.264 0.32721 11.3626 0.946757 11.0613L7.10885 8.06472C7.6312 7.81065 8.0478 7.38145 8.28597 6.85171L11.0963 0.602306C11.3788 -0.0259072 12.2816 0.00653915 12.5183 0.653458L18.4871 16.9645Z"
                                          fill="#F65A0B"/>
                                </svg>
                            </span>
                        </span>
                    <?php endif;
                    if (!empty($settings['title_middle'])): ?>
                        <h2 class="title"><?php echo wp_kses($settings['title_middle'], true); ?></h2>
                    <?php endif;
                    if (!empty($settings['title_bottom'])): ?>
                        <span class="sub-title sub-title--two">
                            <span data-parallax='{"x":-50,"y":-70}'>
                                <svg width="19" height="18" viewBox="0 0 19 18" fill="none"
                                     xmlns="http://www.w3.org/2000/svg">
                                    <path d="M0.779727 1.06017C0.567847 0.453069 1.15106 -0.130154 1.75818 0.0817293L18.1571 5.80495C18.8075 6.03193 18.8535 6.93416 18.2295 7.22609L12.0231 10.1298C11.497 10.376 11.074 10.7989 10.8279 11.325L7.92409 17.5315C7.63216 18.1554 6.72993 18.1094 6.50295 17.459L0.779727 1.06017Z"
                                          fill="#E2EA46"/>
                                </svg><span class="sub-title--inner"><span><?php echo wp_kses($settings['title_bottom'], true); ?></span></span>
                            </span>
                        </span>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Brand_V5());