<?php

/**
 * Elementor Single Widget
 * @package xpress-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Seargin_Casestudy_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-casestudy-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Casestudy V3', 'xpress-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {


        $this->start_controls_section(
            'casestudy_option',
            [
                'label' => esc_html__('Casestudy', 'xpress-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'casestudyorder',
            [
                'label' => esc_html__('Casestudy Order', 'xpress-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC' => esc_html__('Ascending', 'xpress-core'),
                    'DESC' => esc_html__('Descending', 'xpress-core'),
                ],
            ]
        );
        $this->add_control(
            'casestudy_per_page',
            [
                'label' => __('Casestudy Per Page', 'xpress-core'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 3,
            ]
        );
        $this->add_control(
            'casestudy_categories',
            [
                'type' => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Casestudy Categories', 'xpress-core'),
                'options' => innomax_casestudy_category(),
                'label_block' => true,
                'multiple' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_cat_style',
            [
                'label' => esc_html__('Casestudy Category', 'xpress-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'nav_padding',
            [
                'label' => esc_html__('Nav Padding', 'xpress-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy__menu button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nav_typography',
                'selector' => '{{WRAPPER}} .xb-casestudy__menu button',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'xpress-core'),
            ]
        );

        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy__menu button' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav-bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy__menu button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'xpress-core'),
            ]
        );

        $this->add_control(
            'h-nav-c',
            [
                'label' => esc_html__('Nav Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy__menu button.active' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xb-casestudy__menu button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h-nav-bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy__menu button.active' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .xb-casestudy__menu button:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_list_style',
            [
                'label' => esc_html__('Casestudy List', 'xpress-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'port_border_color',
            [
                'label' => esc_html__('Border Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy .xb-item--content' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'port_padding',
            [
                'label' => esc_html__('Padding', 'xpress-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy .xb-item--content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'port_cat_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'cat_color',
            [
                'label' => esc_html__('Category Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy .xb-item--cat' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typography',
                'selector' => '{{WRAPPER}} .xb-casestudy .xb-item--cat',
            ]
        );
        $this->add_control(
            'port_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'xpress-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-casestudy .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-casestudy .xb-item--title',
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <div class="similar-casestudy">
            <div class="row mt-none-30">
                <?php
                $args = array(
                    'post_type' => 'innomax_casestudy',
                    'posts_per_page' => !empty($settings['casestudy_per_page']) ? $settings['casestudy_per_page'] : 1,
                    'ignore_sticky_posts' => true,
                    'post_status' => 'publish',
                    'suppress_filters' => false,
                    'order' => $settings['casestudyorder'],
                );

                if (!empty($settings['casestudy_categories'])) {
                    $args['tax_query'] = array(
                        array(
                            'taxonomy' => 'casestudy_cat',
                            'field' => 'id',
                            'terms' => $settings['casestudy_categories'],
                            'operator' => 'IN',
                        ),
                    );
                }

                $query = new \WP_Query($args);

                if ($query->have_posts()) :
                    while ($query->have_posts()) :
                        $query->the_post();
                        $idd = get_the_ID();

                        $casestudyInerCates = get_the_terms($idd, 'casestudy_cat');
                        if ($casestudyInerCates && !is_wp_error($casestudyInerCates)) {
                            $casestudy_cat_list = array();
                            foreach ($casestudyInerCates as $cate) {
                                $casestudy_cat_list[] = $cate->slug;
                            }
                            $casestudy_cate_asign_list = join(' ', $casestudy_cat_list);
                        } else {
                            $casestudy_cate_asign_list = '';
                        }
                        ?>
                        <div class="col-lg-4 col-md-6 mt-30 <?php echo esc_attr($casestudy_cate_asign_list) ?>">
                            <div class="casestudy-item">
                                <div class="casestudy-img">
                                    <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('innomax-casestudy'); ?></a>
                                    <div class="content_wrap">
                                        <h3 class="item_title"><?php the_title(); ?></h3>
                                        <?php
                                        if (!empty($casestudyInerCates)) {
                                            echo '<span class="item_tag">' . esc_attr($cate->name) . '</span>';
                                        }
                                        ?>
                                    </div>
                                </div>
                                <a class="xb-overlay" href="<?php the_permalink(); ?>"></a>
                            </div>
                        </div>
                    <?php
                    endwhile;
                    wp_reset_query();
                else:
                    echo '<p>No case studies found in the selected category.</p>';
                endif;
                ?>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Seargin_Casestudy_V3());