<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Casestudy_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-casestudy-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Casestudy V4', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {


        $this->start_controls_section(
            'casestudy_option',
            [
                'label' => esc_html__('Casestudy', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'casestudyorder',
            [
                'label' => esc_html__('Casestudy Order', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC' => esc_html__('Ascending', 'innomax-core'),
                    'DESC' => esc_html__('Descending', 'innomax-core'),
                ],
            ]
        );
        $this->add_control(
            'casestudy_per_page',
            [
                'label' => __('Casestudy Per Page', 'innomax-core'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 9,
            ]
        );
        $this->add_control(
            'casestudy_categories',
            [
                'type' => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Casestudy Categories', 'innomax-core'),
                'options' => innomax_casestudy_category(),
                'label_block' => true,
                'multiple' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_cat_style',
            [
                'label' => esc_html__('Casestudy Category', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'nav_padding',
            [
                'label' => esc_html__('Nav Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .team-menu button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nav_typography',
                'selector' => '{{WRAPPER}} .team-menu button',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-menu button' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav-bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-menu button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Active', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h-nav-c',
            [
                'label' => esc_html__('Nav Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-menu button.active' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h-nav-bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-menu button::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_list_style',
            [
                'label' => esc_html__('Casestudy List', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'port_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'port_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_bg-c',
            [
                'label' => esc_html__('Title BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_title' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_title',
            ]
        );
        $this->add_control(
            'port_cat_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'cat_color',
            [
                'label' => esc_html__('Category Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_tag' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'cat_bg-c',
            [
                'label' => esc_html__('Category BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_tag' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typography',
                'selector' => '{{WRAPPER}} .casestudy-item .casestudy-img .content_wrap .item_tag',
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $selected_categories = !empty($settings['casestudy_categories']) ? $settings['casestudy_categories'] : [];

        if (!empty($selected_categories)) {
            $casestudyCategory = get_terms([
                'taxonomy' => 'casestudy_cat',
                'include' => $selected_categories,
            ]);
        } else {
            $casestudyCategory = get_terms('casestudy_cat');
        }

        ?>
        <div class="row justify-content-center">
            <div class="col-lg-8 text-center">
                <div class="team-menu casestudy-menu">
                    <button class="active" data-filter="*"><?php esc_html_e('View all', 'innomax-core') ?></button>
                    <?php
                    if (!empty($casestudyCategory) && !is_wp_error($casestudyCategory)):
                        foreach ($casestudyCategory as $cate):
                            ?>
                            <button data-filter=".<?php echo esc_attr($cate->slug) ?>"
                                    class=""><?php echo esc_html($cate->name) ?></button>
                        <?php endforeach; endif; ?>
                </div>
            </div>
        </div>
        <div class="casestudy-content mt-70">
            <div class="row grid mt-none-30">
                <?php
                $args = array(
                    'post_type' => 'innomax_casestudy',
                    'posts_per_page' => !empty($settings['casestudy_per_page']) ? $settings['casestudy_per_page'] : 1,
                    'ignore_sticky_posts' => true,
                    'post_status' => 'publish',
                    'suppress_filters' => false,
                    'order' => $settings['casestudyorder'],
                );

                if (!empty($selected_categories)) {
                    $args['tax_query'] = array(
                        array(
                            'taxonomy' => 'casestudy_cat',
                            'field' => 'term_id',
                            'terms' => $selected_categories,
                        ),
                    );
                }

                $query = new \WP_Query($args);
                if ($query->have_posts()):

                    while ($query->have_posts()) {
                        $query->the_post();
                        $idd = get_the_ID();

                        $casestudyInerCates = get_the_terms($idd, 'casestudy_cat');
                        if ($casestudyInerCates && !is_wp_error($casestudyInerCates)) {
                            $casestudy_cat_list = array();
                            foreach ($casestudyInerCates as $cate) {
                                $casestudy_cat_list[] = $cate->slug;
                            }
                            $casestudy_cate_asign_list = join(' ', $casestudy_cat_list);
                        } else {
                            $casestudy_cate_asign_list = '';
                        }

                        ?>
                        <div class="col-lg-4 col-md-6 grid-item mt-25 <?php echo esc_attr($casestudy_cate_asign_list) ?>">
                            <div class="casestudy-item">
                                <div class="casestudy-img">
                                    <a href="<?php the_permalink(); ?>">
                                        <?php the_post_thumbnail('innomax-casestudy'); ?>
                                    </a>
                                    <div class="content_wrap">
                                        <h3 class="item_title"><?php the_title(); ?></h3>
                                        <?php
                                        if (!empty($casestudyInerCates)) {
                                            echo '<span class="item_tag">' . esc_attr($cate->name) . '</span>';
                                        }
                                        ?>
                                    </div>
                                </div>
                                <a class="xb-overlay" href="<?php the_permalink(); ?>"></a>
                            </div>
                        </div>
                        <?php
                    }
                    wp_reset_query();
                endif;
                ?>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Casestudy_V4());