<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Casestudy extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-casestudy';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Casestudy', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'container_width',
            [
                'label' => esc_html__('Container Width', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'width',
            [
                'label' => esc_html__('Width', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 1320,
                ],
                'selectors' => [
                    '{{WRAPPER}} .container' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_option',
            [
                'label' => esc_html__('Casestudy', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Casestudy', 'innomax-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'innomax-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'textdomain'),
                'label_block' => true,
                'default' => esc_html__('Read case study', 'textdomain'),
            ]
        );
        $repeater->add_control(
            'cs_info_1',
            [
                'label' => esc_html__('Info One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'cs_number_1',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'cs_content_1',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'cs_info_2',
            [
                'label' => esc_html__('Info Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'cs_number_2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'cs_content_2',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'cs_info_3',
            [
                'label' => esc_html__('Info Three', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'cs_number_3',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'cs_content_3',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'brand_logo_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $repeater->add_control(
            'brand_logo',
            [
                'label' => esc_html__('Brand Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Casestudy using Elementor. You can find it under <a href="%s" target="_blank">Casestudys</a>.', 'innomax-core'),
                        admin_url('edit.php?post_type=innomax_casestudy')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'casestudy_style_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'cs_padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'overly_bg-c',
            [
                'label' => esc_html__('Overly Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item::before' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sa-project-item .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .sa-project-item .xb-item--content',
            ]
        );
        $this->add_control(
            'btn_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'btn-c',
            [
                'label' => esc_html__('Button Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_border-c',
            [
                'label' => esc_html__('Button Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--border::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_icon_bg-c',
            [
                'label' => esc_html__('Button Icon BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .thm-btn span' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_icon-c',
            [
                'label' => esc_html__('Button Icon Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .thm-btn span svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'right_content_hr',
            [
                'label' => esc_html__('Right Content Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'r_number-c',
            [
                'label' => esc_html__('Number Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'r_number_typography',
                'selector' => '{{WRAPPER}} .sa-project-item .xb-item--number',
            ]
        );

        $this->add_control(
            'r_content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .xb-item--text' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'r_content_typography',
                'selector' => '{{WRAPPER}} .sa-project-item .xb-item--text',
            ]
        );
        $this->add_control(
            'left_border_1-c',
            [
                'label' => esc_html__('Left Border Color One', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .xb-item--item::before' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'left_border_2-c',
            [
                'label' => esc_html__('Left Border Color Two', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .border-blue::before' => 'background: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'left_border_3-c',
            [
                'label' => esc_html__('Left Border Color Three', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-project-item .border-sky::before' => 'background: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'brand_logo_style_hr',
            [
                'label' => esc_html__('Brand Logo Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'brand_logo_border-c',
            [
                'label' => esc_html__('Brand Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-projecr_brand' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'brand_logo_border2-c',
            [
                'label' => esc_html__('Brand Border Two Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .seo-project-slider-nav::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'brand_logo_border3-c',
            [
                'label' => esc_html__('Brand Border Active Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-brand-item .xb-img::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $arrow = INNOMAX_DIR_URL . 'assets/img/casestudy_arrow.svg';

        ?>
        <div class="sa-project_wrapper">
            <div class="seo-project-slider-inner">
                <div class="seo-project-slider">
                    <?php
                    foreach ($settings['lists'] as $a) {
                        if (isset($a['template']) && !empty($a['template'])) {
                            $casestudy_post = get_post($a['template']);
                            if ($casestudy_post instanceof \WP_Post) {
                                $casestudy_title = esc_html($casestudy_post->post_title);
                                $casestudy_permalink = esc_url(get_permalink($casestudy_post));
                                $casestudy_image_url = get_the_post_thumbnail_url($casestudy_post, 'full');
                                ?>
                                <div class="sa-project-item bg_img" <?php if (!empty($casestudy_image_url)): ?>
                                     style="background-image: url('<?php echo esc_url($casestudy_image_url); ?>') <?php endif; ?>">
                                    <div class="xb-item--inner ul_li_between pos-rel z-1">
                                        <div class="xb-item--project_title">
                                            <h2 class="xb-item--title"><?php echo $casestudy_title; ?></h2>
                                            <?php if (!empty($a['content'])): ?>
                                                <p class="xb-item--content"><?php echo wp_kses($a['content'], true); ?></p>
                                            <?php endif; ?>
                                            <?php if (!empty($a['btn_label'])): ?>
                                                <div class="xb-btn mt-50">
                                                    <a href="<?php echo $casestudy_permalink; ?>"
                                                       class="thm-btn thm-btn--border"><?php echo esc_html($a['btn_label']); ?>
                                                        <span><svg width="11" height="11" viewBox="0 0 11 11"
                                                                   fill="none"
                                                                   xmlns="http://www.w3.org/2000/svg">
                                                <path d="M10.7354 3.14709C10.8167 2.74092 10.5533 2.3458 10.1471 2.26456L3.52817 0.94078C3.122 0.859546 2.72688 1.12296 2.64565 1.52913C2.56441 1.9353 2.82782 2.33042 3.23399 2.41165L9.11748 3.58835L7.94078 9.47183C7.85955 9.878 8.12296 10.2731 8.52913 10.3544C8.9353 10.4356 9.33042 10.1722 9.41165 9.76601L10.7354 3.14709ZM1.41603 9.62404L10.416 3.62404L9.58398 2.37596L0.583975 8.37596L1.41603 9.62404Z"
                                                      fill="#0C111D"/>
                                              </svg></span></a>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                        <div class="xb-item--item-box mt-none-50">
                                            <div class="xb-item--item">
                                                <?php if (!empty($a['cs_number_1'])): ?>
                                                    <span class="xb-item--number"><?php echo esc_html($a['cs_number_1']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($a['cs_content_1'])): ?>
                                                    <span class="xb-item--text"><?php echo esc_html($a['cs_content_1']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                            <div class="xb-item--item border-blue">
                                                <?php if (!empty($a['cs_number_2'])): ?>
                                                    <span class="xb-item--number"><?php echo esc_html($a['cs_number_2']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($a['cs_content_2'])): ?>
                                                    <span class="xb-item--text"><?php echo esc_html($a['cs_content_2']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                            <div class="xb-item--item border-sky">
                                                <?php if (!empty($a['cs_number_3'])): ?>
                                                    <span class="xb-item--number"><?php echo esc_html($a['cs_number_3']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($a['cs_content_3'])): ?>
                                                    <span class="xb-item--text"><?php echo esc_html($a['cs_content_3']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php }
                        }
                    } ?>
                </div>
            </div>

            <div class="sa-projecr_brand pt-70">
                <div class="container">
                    <div class="seo-project-slider-nav">
                        <?php
                        foreach ($settings['lists'] as $a) {
                            if (isset($a['template']) && !empty($a['template'])) {
                                $casestudy_post = get_post($a['template']);
                                if ($casestudy_post instanceof \WP_Post) {
                                    ?>
                                    <div class="sa-brand-item">
                                        <div class="xb-img">
                                            <?php echo wp_get_attachment_image($a['brand_logo']['id'], 'medium'); ?>
                                        </div>
                                        <div class="xb-line"></div>
                                    </div>
                                <?php }
                            }
                        } ?>
                    </div>
                </div>
            </div>

        </div>


        <?php
    }

    protected
    function template_select()
    {
        $type = 'innomax_casestudy';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'innomax-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected
    function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Casestudy());