<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Contact_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-contact-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Contact V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'image_option',
            [
                'label' => esc_html__('Image Option', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'bg_image2',
            [
                'label' => esc_html__('Background Image Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'shape2',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-contact-wrap::before',
                'fields_options' => [
                    'background' => [
                        'label' => 'Shape Two'
                    ],
                ],
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'subtitle_icon',
            [
                'label' => esc_html__('Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content', [
                'label' => esc_html__('Content', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('List Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'icon-bg-c',
            [
                'label' => esc_html__('Icon Background Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} span' => 'background-color: {{VALUE}}'
                ],
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add List', 'textdomain'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'form_option',
            [
                'label' => esc_html__('Form', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'c_subtitle_icon',
            [
                'label' => esc_html__('Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'c_sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'c_title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'shortcode', [
                'label' => esc_html__('Form Shortcode', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'subtitle_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sec-title--three .sub-title span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'sub_title_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .sub-title' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title',
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .title',
            ]
        );
        $this->add_control(
            'content_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .award-top .content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .award-top .content',
            ]
        );
        $this->add_control(
            'list_heading',
            [
                'label' => esc_html__('List Heading', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'list-c',
            [
                'label' => esc_html__('List Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-contact-wrap .xb-item--cont_info li' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'list_typography',
                'selector' => '{{WRAPPER}} .cs-contact-wrap .xb-item--cont_info li',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'form_option_style',
            [
                'label' => esc_html__('Form', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'field-c',
            [
                'label' => esc_html__('Field Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box input' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box textarea' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'field-bg-c',
            [
                'label' => esc_html__('Field BG Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box input' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box textarea' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box .nice-select' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'field-border-c',
            [
                'label' => esc_html__('Field Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box input' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box textarea' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box .nice-select' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'field-border-focus-c',
            [
                'label' => esc_html__('Field Border Focus Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box input:focus' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box textarea:focus' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cs-contact-form .input-field .input-box .nice-select:focus' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'field_typography',
                'selector' => '{{WRAPPER}} .cs-contact-form .input-field .input-box input, 
                                {{WRAPPER}} .cs-contact-form .input-field .input-box textarea,
                                {{WRAPPER}} .cs-contact-form .input-field .input-box select',
            ]
        );

        $this->add_control(
            'btn_style_hr',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .hero-style-three .hero-btn a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .hero-style-three .hero-btn a',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="contact contact-bg pt-140 pb-100 pos-rel bg_img"
            <?php if (!empty($settings['bg_image']['url'])): ?>
                 style="background-image: url('<?php echo esc_url($settings['bg_image']['url']); ?>') <?php endif; ?>">
            <div class="container">
                <div class="contact-two pos-rel bg_img" <?php if (!empty($settings['bg_image2']['url'])): ?>
                     style="background-image: url('<?php echo esc_url($settings['bg_image2']['url']); ?>') <?php endif; ?>">
                    <div class="row mt-none-30">
                        <div class="col-lg-5 mt-30">
                            <div class="cs-contact-wrap">
                                <div class="xb-item--inner">
                                    <div class="sec-title--two sec-title--three mb-25">
                                        <?php if (!empty($settings['sub_title'])): ?>
                                            <span class="sub-title"><?php \Elementor\Icons_Manager::render_icon($settings['subtitle_icon'], ['aria-hidden' => 'true']); ?><span><?php echo esc_html($settings['sub_title']); ?></span></span>
                                        <?php endif; ?>
                                        <?php if (!empty($settings['title'])): ?>
                                            <h2 class="title"><?php echo esc_html($settings["title"]); ?></h2>
                                        <?php endif; ?>
                                    </div>
                                    <?php if (!empty($settings['content'])): ?>
                                        <p class="xb-item--content"><?php echo wp_kses($settings['content'], true); ?></p>
                                    <?php endif; ?>
                                    <ul class="xb-item--cont_info list-unstyled">
                                        <?php
                                        foreach ($settings['lists'] as $list):
                                            ?>
                                            <li class="elementor-repeater-item-<?php echo esc_attr( $list['_id'] ); ?>">
                                                <span><?php \Elementor\Icons_Manager::render_icon($list['icon'], ['aria-hidden' => 'true']); ?></span> <?php echo esc_html($list['text']); ?>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                    <?php if (!empty($settings['image']['id'])): ?>
                                        <div class="xb-item--img">
                                            <?php echo wp_get_attachment_image($settings['image']['id'], 'full'); ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-7 mt-30">
                            <div class="cs-contact-wrap cs-contact-form">
                                <div class="sec-title--two sec-title--three">
                                    <?php if (!empty($settings['c_sub_title'])): ?>
                                        <span class="sub-title"><?php \Elementor\Icons_Manager::render_icon($settings['c_subtitle_icon'], ['aria-hidden' => 'true']); ?><span><?php echo esc_html($settings['c_sub_title']); ?></span></span>
                                    <?php endif; ?>
                                    <?php if (!empty($settings['c_title'])): ?>
                                        <h2 class="title"><?php echo esc_html($settings['c_title']); ?></h2>
                                    <?php endif; ?>
                                </div>
                                <?php if (!empty($settings['shortcode'])): ?>
                                    <div class="contact-form">
                                        <?php echo do_shortcode($settings['shortcode']); ?>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php if (!empty($settings['shape']['id'])): ?>
                <div class="xb-shape"><?php echo wp_get_attachment_image($settings['shape']['id'], 'full'); ?></div>
            <?php endif; ?>
        </section>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Contact_V2());