<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_CTA_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-cta-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('CTA V4', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'icon1',
            [
                'label' => esc_html__('Icon One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon2',
            [
                'label' => esc_html__('Icon Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon3',
            [
                'label' => esc_html__('Icon Three', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon4',
            [
                'label' => esc_html__('Icon Four', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon5',
            [
                'label' => esc_html__('Icon Five', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon6',
            [
                'label' => esc_html__('Icon Six', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'icon7',
            [
                'label' => esc_html__('Icon Seven', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'shape_option',
            [
                'label' => esc_html__('Shape', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'shape1',
            [
                'label' => esc_html__('Shape 1', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape2',
            [
                'label' => esc_html__('Shape 2', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'cta_style_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'cta_title_c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--five .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cta_title_typography',
                'selector' => '{{WRAPPER}} .sec-title--five .title',
            ]
        );
        $this->add_control(
            'btn_style_hr',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'btn_radius',
            [
                'label' => esc_html__('Border Radius', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .thm-btn',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <section class="cta cta-height pos-rel z-1 pt-165" data-bg-color="#212877">
            <div class="container">
                <div class="row align-items-end">
                    <div class="col-12">
                        <div class="cta-icons">
                            <?php if (!empty($settings['icon1']['id'])): ?>
                                <div class="icon icon--1">
                                    <?php echo wp_get_attachment_image($settings['icon1']['id'], 'full', false, ['data-parallax' => '{"x":-20,"y":-30}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon2']['id'])): ?>
                                <div class="icon icon--2">
                                    <?php echo wp_get_attachment_image($settings['icon2']['id'], 'full', false, ['data-parallax' => '{"x":-30,"y":-20}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon3']['id'])): ?>
                                <div class="icon icon--3">
                                    <?php echo wp_get_attachment_image($settings['icon3']['id'], 'full', false, ['data-parallax' => '{"x":-10,"y":-30}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon4']['id'])): ?>
                                <div class="icon icon--4">
                                    <?php echo wp_get_attachment_image($settings['icon4']['id'], 'full', false, ['data-parallax' => '{"y":-40}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon5']['id'])): ?>
                                <div class="icon icon--5">
                                    <?php echo wp_get_attachment_image($settings['icon5']['id'], 'full', false, ['data-parallax' => '{"x":10,"y":-30}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon6']['id'])): ?>
                                <div class="icon icon--6">
                                    <?php echo wp_get_attachment_image($settings['icon6']['id'], 'full', false, ['data-parallax' => '{"x":30,"y":-20}']); ?>
                                </div>
                            <?php endif;
                            if (!empty($settings['icon7']['id'])): ?>
                                <div class="icon icon--7">
                                    <?php echo wp_get_attachment_image($settings['icon7']['id'], 'full', false, ['data-parallax' => '{"x":20,"y":-30}']); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                        <?php if (!empty($settings['shape']['id'])): ?>
                            <div class="cta-image">
                                <?php echo wp_get_attachment_image($settings['shape']['id'], 'full'); ?>
                            </div>
                        <?php endif; ?>
                        <div class="cd-cta">
                            <?php if (!empty($settings['title'])): ?>
                                <div class="sec-title--five text-center">
                                    <h2 class="title wow fadeInUp"><?php echo wp_kses($settings['title'], true); ?></h2>
                                </div>
                            <?php endif; ?>
                            <?php if (!empty($settings['btn_label'])): ?>
                                <div class="xb-btn mt-20 text-center wow fadeInUp" data-wow-delay="150ms">
                                    <a href="<?php echo esc_url($settings['btn_link']['url']); ?>"
                                       class="thm-btn thm-btn--devops thm-btn--devops_yellow"><?php echo esc_html($settings['btn_label']); ?></a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="cd-sec-shape">
                <?php if (!empty($settings['shape1']['id'])): ?>
                    <div class="shape shape--two">
                        <?php echo wp_get_attachment_image($settings['shape1']['id'], 'full'); ?>
                    </div>
                <?php endif;
                if (!empty($settings['shape2']['id'])): ?>
                    <div class="shape shape--three">
                        <?php echo wp_get_attachment_image($settings['shape2']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
            </div>
        </section>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_CTA_V4());