<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Features_V6 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-features-v6';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Features V6', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'feature_top_option',
            [
                'label' => esc_html__('Feature Top', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title1',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content1',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('List Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icons',
            [
                'label' => esc_html__('Add Icon List', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'feature_left_option',
            [
                'label' => esc_html__('Feature Left', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'icon2',
            [
                'label' => esc_html__('Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content2',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'feature_right_option',
            [
                'label' => esc_html__('Feature Right', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'icon3',
            [
                'label' => esc_html__('Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title3',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content3',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'feature_bottom_option',
            [
                'label' => esc_html__('Feature Bottom', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title4',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content4',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('List Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icons2',
            [
                'label' => esc_html__('Add Icon List', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'image_option',
            [
                'label' => esc_html__('Image Bottom', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'logo_link',
            [
                'label' => esc_html__('Logo Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'arrow1',
            [
                'label' => esc_html__('Arrow Icon One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'arrow2',
            [
                'label' => esc_html__('Arrow Icon Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'arrow3',
            [
                'label' => esc_html__('Arrow Icon Three', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'arrow4',
            [
                'label' => esc_html__('Arrow Icon Four', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'arrow5',
            [
                'label' => esc_html__('Arrow Icon Five', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'feature_bg-c',
            [
                'label' => esc_html__('Feature BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-item::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .hd-feature-item .xb-item--title',
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .cd-feature .title',
            ]
        );
        $this->add_control(
            'icon_title-c',
            [
                'label' => esc_html__('Icon Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-item .xb-item--meta li span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'icon_title_typography',
                'selector' => '{{WRAPPER}} .hd-feature-item .xb-item--meta li span',
            ]
        );
        $this->add_control(
            'logo_style_hr',
            [
                'label' => esc_html__('Logo Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'logo_border-c',
            [
                'label' => esc_html__('Logo Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-button' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'logo_background-c',
            [
                'label' => esc_html__('Logo Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hd-feature-button span' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="xb-feature-wrap pos-rel">
            <div class="hd-feature--top">
                <div class="hd-feature-item text-center">
                    <?php if (!empty($settings['title1'])): ?>
                        <h3 class="xb-item--title"><?php echo esc_html($settings['title1']); ?></h3>
                    <?php endif; ?>
                    <?php if (!empty($settings['content1'])): ?>
                        <p class="xb-item--content"><?php echo wp_kses($settings['content1'], true); ?></p>
                    <?php endif; ?>
                    <ul class="xb-item--meta list-unstyled">
                        <?php
                        foreach ($settings['icons'] as $icon):
                            ?>
                            <li>
                                <?php echo wp_get_attachment_image($icon['icon']['id'], 'thumbnail'); ?>
                                <span><?php echo esc_html($icon['title']); ?></span>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>
            <div class="hd-feature--middle">
                <div class="hd-feature-item">
                    <?php echo wp_get_attachment_image($settings['icon2']['id'], 'thumbnail'); ?>
                    <?php if (!empty($settings['title2'])): ?>
                        <h3 class="xb-item--title"><?php echo esc_html($settings['title2']); ?></h3>
                    <?php endif; ?>
                    <?php if (!empty($settings['content2'])): ?>
                        <p class="xb-item--content"><?php echo wp_kses($settings['content2'], true); ?></p>
                    <?php endif; ?>
                </div>
                <div class="hd-button-box pos-rel">
                    <?php if (!empty($settings['logo']['id'])): ?>
                        <a href="<?php echo esc_url($settings['logo_link']['url']); ?>" class="hd-feature-button">
                            <span><?php echo wp_get_attachment_image($settings['logo']['id'], 'medium'); ?></span>
                        </a>
                    <?php endif; ?>
                    <div class="xb-arrow">
                        <?php if (!empty($settings['arrow1']['id'])): ?>
                            <div class="arrow arrow--one"><?php echo wp_get_attachment_image($settings['arrow1']['id'], 'thumbnail'); ?></div>
                        <?php endif;
                        if (!empty($settings['arrow2']['id'])): ?>
                            <div class="arrow arrow--two"><?php echo wp_get_attachment_image($settings['arrow2']['id'], 'thumbnail'); ?></div>
                        <?php endif;
                        if (!empty($settings['arrow3']['id'])): ?>
                            <div class="arrow arrow--three"><?php echo wp_get_attachment_image($settings['arrow3']['id'], 'thumbnail'); ?></div>
                        <?php endif;
                        if (!empty($settings['arrow4']['id'])): ?>
                            <div class="arrow arrow--four"><?php echo wp_get_attachment_image($settings['arrow4']['id'], 'thumbnail'); ?></div>
                        <?php endif;
                        if (!empty($settings['arrow5']['id'])): ?>
                            <div class="arrow arrow--five"><?php echo wp_get_attachment_image($settings['arrow5']['id'], 'thumbnail'); ?></div>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="hd-feature-item">
                    <?php echo wp_get_attachment_image($settings['icon3']['id'], 'thumbnail'); ?>
                    <?php if (!empty($settings['title3'])): ?>
                        <h3 class="xb-item--title"><?php echo esc_html($settings['title3']); ?></h3>
                    <?php endif; ?>
                    <?php if (!empty($settings['content3'])): ?>
                        <p class="xb-item--content"><?php echo wp_kses($settings['content3'], true); ?></p>
                    <?php endif; ?>
                </div>
            </div>
            <div class="hd-feature--bottom">
                <div class="hd-feature-item text-center">
                    <?php if (!empty($settings['title4'])): ?>
                        <h3 class="xb-item--title"><?php echo esc_html($settings['title4']); ?></h3>
                    <?php endif; ?>
                    <?php if (!empty($settings['content4'])): ?>
                        <p class="xb-item--content"><?php echo wp_kses($settings['content4'], true); ?></p>
                    <?php endif; ?>
                    <ul class="xb-item--meta list-unstyled ul_li_between">
                        <?php
                        foreach ($settings['icons2'] as $icon):
                            ?>
                            <li>
                                <?php echo wp_get_attachment_image($icon['icon']['id'], 'thumbnail'); ?>
                                <span><?php echo esc_html($icon['title']); ?></span>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>
            <div class="xb-shape">
                <span></span>
            </div>
        </div>
        <?php
    }

}

Plugin::instance()->widgets_manager->register(new Innomax_Features_V6());