<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Features extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-features';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Features', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'table_head',
            [
                'label' => esc_html__('Table Head', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'feature_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Feature Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'other_agency_text',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Other Agency Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'table_data',
            [
                'label' => esc_html__('Table Head', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'feature_text',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Feature Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'icon1',
            [
                'label' => esc_html__('Icon One', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'icon2',
            [
                'label' => esc_html__('Icon Two', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add List', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ feature_text }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'head_title-c',
            [
                'label' => esc_html__('Head Title Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr th' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'head_title_typography',
                'selector' => '{{WRAPPER}} .feature-table tr th',
            ]
        );
        $this->add_control(
            'head_padding',
            [
                'label' => esc_html__('Head Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr td:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .feature-table tr th:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'table_style',
            [
                'label' => esc_html__('Table Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr td' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'border-c',
            [
                'label' => esc_html__('Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr td' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr td' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .feature-table tr td',
            ]
        );
        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Review Info', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'feature_active_hr',
            [
                'label' => esc_html__('Feature Active Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'feature_active_bg-c',
            [
                'label' => esc_html__('Feature Active BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .feature-table tr td:nth-child(2)' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .feature-table tr th:nth-child(2)' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <table class="feature-table">
            <thead>
            <tr>
                <th><?php echo esc_html($settings['feature_title']); ?></th>
                <th><?php echo wp_get_attachment_image($settings['logo']['id'], 'medium', false, ['class' => 'feature_table_logo']); ?></th>
                <th><?php echo esc_html($settings['other_agency_text']); ?></th>
            </tr>
            </thead>
            <tbody class="table-body">
            <?php
            foreach ($settings['lists'] as $list):
                ?>
                <tr>
                    <td><?php echo esc_html($list['feature_text']); ?></td>
                    <td><?php \Elementor\Icons_Manager::render_icon($list['icon1'], ['aria-hidden' => 'true']); ?></td>
                    <td><?php \Elementor\Icons_Manager::render_icon($list['icon2'], ['aria-hidden' => 'true']); ?></td>
                </tr>
            <?php endforeach; ?>
            </tbody>
        </table>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Features());