<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Funfact extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-funfact';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Funfact', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'design_style',
            [
                'label' => __('Design Style', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'one' => __('Style 1', 'innomax-core'),
                    'two' => __('Style 2', 'innomax-core'),
                    'three' => __('Style 3', 'innomax-core'),
                ],
                'default' => 'style_1',
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Number', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Text', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'image1',
            [
                'label' => esc_html__('Image One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'image2',
            [
                'label' => esc_html__('Image Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'textdomain'),
            ]
        );

        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .fanfact-item .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .fanfact-item .xb-item--content',
            ]
        );
        $this->add_control(
            'number_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'number-c',
            [
                'label' => esc_html__('Number Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'number_typography',
                'selector' => '{{WRAPPER}} .fanfact-item .xb-item--number',
            ]
        );
        $this->add_control(
            'text_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'text-c',
            [
                'label' => esc_html__('Text Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .xb-item--text' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'selector' => '{{WRAPPER}} .fanfact-item .xb-item--text',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'textdomain'),
            ]
        );

        $this->add_control(
            'hbg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'htitle_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'htitle-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item:hover .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hcontent_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'hcontent-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item:hover .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hnumber_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'hnumber-c',
            [
                'label' => esc_html__('Number Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item:hover .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'htext_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'htext-c',
            [
                'label' => esc_html__('Text Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item:hover .xb-item--text' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h_img_border_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'img_border-c',
            [
                'label' => esc_html__('Image Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .fanfact-icon .icon' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hicon_bg_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'icon_bg-c',
            [
                'label' => esc_html__('Icon Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .fanfact-icon .icon--three' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'icon_border-c',
            [
                'label' => esc_html__('Icon Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .fanfact-icon .icon' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hicon-c',
            [
                'label' => esc_html__('Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .fanfact-item .fanfact-icon .icon svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="innomax-funfact">
            <div class="row mt-none-40 justify-content-center">
                <?php
                $delay = 0;
                foreach ($settings['lists'] as $list):
                    $design_style_suffix = !empty($list['design_style']) ? esc_attr($list['design_style']) : 'one';
                    ?>
                    <div class="col-lg-4 col-md-8 mt-40">
                        <div class="fanfact-item wow fadeInUp" data-wow-delay="<?php echo $delay; ?>ms"
                             data-wow-duration="600ms">
                            <div class="xb-item--holder pos-rel z-1">
                                <?php if (!empty($list['title'])): ?>
                                    <h5 class="xb-item--title"><?php echo esc_html($list['title']); ?></h5>
                                <?php endif; ?>
                                <?php if (!empty($list['content'])): ?>
                                    <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                <?php endif; ?>
                                <?php if (!empty($list['number'])): ?>
                                    <span class="xb-item--number"><?php echo wp_kses($list['number'], true); ?></span>
                                <?php endif; ?>
                                <?php if (!empty($list['text'])): ?>
                                    <span class="xb-item--text"><?php echo esc_html($list['text']); ?></span>
                                <?php endif; ?>
                            </div>
                            <div class="fanfact-icon fanfact-icon--<?php echo $design_style_suffix; ?>">
                                <?php if (!empty($list['image1']['id'])): ?>
                                    <div class="icon icon--one"><?php echo wp_get_attachment_image($list['image1']['id'], 'medium'); ?></div>
                                <?php endif; ?>
                                <?php if (!empty($list['image2']['id'])): ?>
                                    <div class="icon icon--two"><?php echo wp_get_attachment_image($list['image2']['id'], 'medium'); ?></div>
                                <?php endif; ?>
                                <div class="icon icon--three"><?php \Elementor\Icons_Manager::render_icon($list['icon'], ['aria-hidden' => 'true']); ?></div>
                            </div>
                        </div>
                    </div>
                    <?php
                    $delay += 150;
                endforeach; ?>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Funfact());