<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Hero_Four extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-hero-four';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Hero Four', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_hr',
            [
                'label' => esc_html__('Button', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'shape_hr',
            [
                'label' => esc_html__('Share', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'shape1',
            [
                'label' => esc_html__('Shape One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape2',
            [
                'label' => esc_html__('Shape Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape3',
            [
                'label' => esc_html__('Shape Three', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape4',
            [
                'label' => esc_html__('Shape Four', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape5',
            [
                'label' => esc_html__('Shape Five', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'video_url_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'video_url',
            [
                'label' => esc_html__('Video URL', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'hero_title_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .hero-style-three .xb-hero .xb-item--title',
                'fields_options' => [
                    'background' => [
                        'label' => 'Title Color'
                    ],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .hero-style-three .xb-hero .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hero-style-three .xb-hero .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .hero-style-three .xb-hero .xb-item--content',
            ]
        );

        $this->add_control(
            'btn_style_hr',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .hero-style-three .hero-btn a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .hero-style-three .hero-btn a',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color1',
            [
                'label' => esc_html__('Background Color 1', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="hero hero-style-three pos-rel pt-120 bg_img" <?php if (!empty($settings['bg_image']['url'])): ?>
                 style="background-image: url('<?php echo esc_url($settings['bg_image']['url']); ?>') <?php endif; ?>">
            <div class="container">
                <div class="hero_wrap pt-90">
                    <div class="xb-hero text-center">
                        <?php if (!empty($settings['title'])): ?>
                            <h1 class="xb-item--title wow skewIn" data-wow-delay="0ms" data-wow-duration="900ms"><?php echo esc_html($settings['title']); ?></h1>
                        <?php endif; ?>
                        <div class="xb-item--holder wow fadeInUp" data-wow-delay="150ms" data-wow-duration="600ms">
                            <?php if (!empty($settings['content'])): ?>
                                <p class="xb-item--content"><?php echo wp_kses($settings['content'], true); ?></p>
                            <?php endif; ?>
                            <?php if (!empty($settings['btn_label'])): ?>
                                <div class="hero-btn">
                                    <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="blc-btn scrollspy-btn">
                                        <span><?php echo esc_html($settings['btn_label']); ?> <i class="far fa-angle-right"></i></span>
                                        <span class="btn-shape">
                                        <svg width="362" height="78" viewBox="0 0 362 78" fill="none"
                                             preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                            <path d="M0.5 22.7183L25.5093 1.39453H337.972L361.5 22.7092V56.5515L337.98 76.6051H25.5093L0.5 55.2813V22.7183Z"
                                                  fill="url(#paint0_linear_1600_9966956)" stroke="#23263C"/>
                                            <defs>
                                              <linearGradient id="paint0_linear_1600_9966956" x1="1.29285" y1="38.9973"
                                                              x2="362" y2="33.9973" gradientUnits="userSpaceOnUse">
                                                <stop offset="0" stop-color="#431DAB"/>
                                                <stop offset="1" stop-color="#AE6DFE"/>
                                              </linearGradient>
                                            </defs>
                                          </svg>
                                    </span>
                                        <span class="btn-shape2">
                                        <svg width="271" height="60" viewBox="0 0 271 60" fill="none"
                                             preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                            <path d="M0.5 17.2308L20.1225 0.5H252.042L270.5 17.2217V43.7692L252.05 59.5H20.1225L0.5 42.7692V17.2308Z"
                                                  fill="#010315" stroke="url(#paint0_linear_1742_661)"/>
                                            <defs>
                                              <linearGradient id="paint0_linear_1742_661" x1="271" y1="61.5556"
                                                              x2="232.791" y2="-3.08978" gradientUnits="userSpaceOnUse">
                                                <stop offset="0" stop-color="#6780D2"/>
                                                <stop offset="1" stop-color="#2F3B8D"/>
                                              </linearGradient>
                                            </defs>
                                          </svg>
                                    </span>
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="xb-shape">
                <?php if (!empty($settings['shape1']['id'])): ?>
                    <div class="shape shape--one">
                        <?php echo wp_get_attachment_image($settings['shape1']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($settings['shape2']['id'])): ?>
                    <div class="shape shape--two">
                        <?php echo wp_get_attachment_image($settings['shape2']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($settings['shape3']['id'])): ?>
                    <div class="shape shape--three">
                        <?php echo wp_get_attachment_image($settings['shape3']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($settings['shape4']['id'])): ?>
                    <div class="shape shape--four">
                        <?php echo wp_get_attachment_image($settings['shape4']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($settings['shape5']['id'])): ?>
                    <div class="shape shape--five">
                        <?php echo wp_get_attachment_image($settings['shape5']['id'], 'full'); ?>
                    </div>
                <?php endif; ?>
            </div>
            <div class="sc_hero_video">
                <video
                        class="responsive-video"
                        loop
                        muted
                        playsinline
                        autoplay>
                    <source src="<?php echo esc_url($settings['video_url']['url']); ?>" type="video/mp4">
                </video>
            </div>
        </section>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Hero_Four());