<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Industrie_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-industrie-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Industrie V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon_default',
            [
                'label' => esc_html__('Icon Default', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'icon_hover',
            [
                'label' => esc_html__('Icon Hover', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Industrie Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'ind_title-c',
            [
                'label' => esc_html__('Title Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .indus-item .xb-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ind_title_typography',
                'selector' => '{{WRAPPER}} .indus-item .xb-title',
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="industries-slider">
            <div class="swiper-wrapper">
                <?php
                $unique_id = isset($settings['_id']) ? esc_attr($settings['_id']) : uniqid('elementor_');
                foreach ($settings['lists'] as $list):
                    ?>
                    <div class="swiper-slide">
                        <div class="cs-industries-item">
                            <div class="xb-item--inner">
                                <?php if (!empty($list['icon_default']['id']) || !empty($list['icon_hover']['id'])): ?>
                                    <div class="xb-item--icon">
                                        <?php
                                        if (!empty($list['icon_default']['id'])) {
                                            echo wp_get_attachment_image($list['icon_default']['id'], 'thumbnail', false, array('class' => 'default'));
                                        }
                                        if (!empty($list['icon_hover']['id'])) {
                                            echo wp_get_attachment_image($list['icon_hover']['id'], 'thumbnail', false, array('class' => 'hover'));
                                        }
                                        ?>
                                    </div>
                                <?php endif; ?>
                                <?php if (!empty($list['title'])): ?>
                                    <h3 class="xb-item--title"><?php echo esc_html($list['title']); ?></h3>
                                <?php endif; ?>
                            </div>
                            <div class="bg-shape1">
                                <svg width="242" height="219" viewBox="0 0 242 219" fill="none"
                                     preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                    <rect x="0.000976562" y="0.000976562" width="241.997" height="219" rx="15"
                                          fill="url(#paint0_linear_1742_6131_<?php echo $unique_id; ?>)"/>
                                    <rect x="0.500977" y="0.500977" width="240.997" height="218" rx="14.5"
                                          stroke="white" stroke-opacity="0.1"/>
                                    <rect width="241.997" height="219" rx="15"
                                          fill="url(#paint1_radial_1742_6131_<?php echo $unique_id; ?>)"/>
                                    <rect x="0.5" y="0.5" width="240.997" height="218" rx="14.5" stroke="white"
                                          stroke-opacity="0.1"/>
                                    <defs>
                                        <linearGradient id="paint0_linear_1742_6131_<?php echo $unique_id; ?>"
                                                        x1="127.049" y1="-29.199"
                                                        x2="127.049" y2="178.851" gradientUnits="userSpaceOnUse">
                                            <stop offset="0" stop-color="#3A3645"/>
                                            <stop offset="1" stop-color="#010315"/>
                                        </linearGradient>
                                        <radialGradient id="paint1_radial_1742_6131_<?php echo $unique_id; ?>" cx="0"
                                                        cy="0" r="1"
                                                        gradientUnits="userSpaceOnUse"
                                                        gradientTransform="translate(120.999) scale(170.124 186.369)">
                                            <stop offset="0" stop-color="white" stop-opacity="0.05"/>
                                            <stop offset="1" stop-color="#050014" stop-opacity="0"/>
                                        </radialGradient>
                                    </defs>
                                </svg>
                            </div>
                            <div class="bg-shape2">
                                <svg width="242" height="219" viewBox="0 0 242 219" fill="none"
                                     preserveAspectRatio="none" xmlns="http://www.w3.org/2000/svg">
                                    <path d="M0.00195312 15C0.00195312 6.71572 6.71768 0 15.002 0H227.002C235.286 0 242.002 6.71573 242.002 15V204C242.002 212.284 235.286 219 227.002 219H15.002C6.71768 219 0.00195312 212.284 0.00195312 204V15Z"
                                          fill="url(#paint0_linear_1742_583_<?php echo $unique_id; ?>)"/>
                                    <path d="M0.501953 15C0.501953 6.99187 6.99382 0.5 15.002 0.5H227.002C235.01 0.5 241.502 6.99187 241.502 15V204C241.502 212.008 235.01 218.5 227.002 218.5H15.002C6.99382 218.5 0.501953 212.008 0.501953 204V15Z"
                                          stroke="url(#paint1_linear_1742_583_<?php echo $unique_id; ?>)"
                                          stroke-opacity="0.7"/>
                                    <defs>
                                        <linearGradient id="paint0_linear_1742_583_<?php echo $unique_id; ?>"
                                                        x1="229.002" y1="55.653"
                                                        x2="216.981" y2="306.586" gradientUnits="userSpaceOnUse">
                                            <stop offset="0" stop-color="#010315"/>
                                            <stop offset="0.29614" stop-color="#090536"/>
                                            <stop offset="0.833198" stop-color="#431DAB" stop-opacity="0.59"/>
                                            <stop offset="1" stop-color="#431DAB"/>
                                        </linearGradient>
                                        <linearGradient id="paint1_linear_1742_583_<?php echo $unique_id; ?>"
                                                        x1="242.002" y1="222.626"
                                                        x2="129.794" y2="175.752" gradientUnits="userSpaceOnUse">
                                            <stop offset="0" stop-color="#6780D2"/>
                                            <stop offset="1" stop-color="#2F3B8D"/>
                                        </linearGradient>
                                    </defs>
                                </svg>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Industrie_V2());