<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Process_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-process-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Process V3', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {


        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title_icon',
            [
                'label' => esc_html__('Sub Title Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'process_style',
            [
                'label' => __('Style', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'left' => __('Left Item', 'innomax-core'),
                    'middle' => __('Center Item', 'innomax-core'),
                    'right' => __('Right Item', 'innomax-core'),
                ],
                'default' => 'left',
            ]
        );
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'arrow',
            [
                'label' => esc_html__('Arrow', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'process',
            [
                'label' => esc_html__('Add Process Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'subtitle_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sec-title--three .sub-title span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'sub_title_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title',
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--three .title',
            ]
        );
        $this->add_control(
            'title_padding',
            [
                'label' => esc_html__('Title Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' => esc_html__('Title Margin', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'content_style_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'process_bg_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .xb-work-item .xb-item--ineer',
                'fields_options' => [
                    'background' => [
                        'label' => 'Process BG Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'title_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-color',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-work-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p_title_typography',
                'selector' => '{{WRAPPER}} .xb-work-item .xb-item--title',
            ]
        );
        $this->add_control(
            'number_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'number-color',
            [
                'label' => esc_html__('Number Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-work-item .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p_number_typography',
                'selector' => '{{WRAPPER}} .xb-work-item .xb-item--number',
            ]
        );

        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $line_icon = INNOMAX_DIR_URL . 'assets/img/das-linee01.png';
        ?>
        <div class="xb-work-wrap pos-rel bg_img pt-100 pb-155" <?php if (!empty($settings['bg_image']['url'])): ?>
             style="background-image: url('<?php echo esc_url($settings['bg_image']['url']); ?>') <?php endif; ?>">
            <div class="sec-title--two sec-title--three text-center mb-60">
                <?php if (!empty($settings['sub_title'])): ?>
                    <span class="sub-title wow fadeInDown"
                          data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><span><?php echo esc_html($settings['sub_title']); ?></span></span>
                <?php endif; ?>
                <div class="clearfix"></div>
                <?php if (!empty($settings['title'])): ?>
                    <h2 class="title wow fadeInDown"
                        data-wow-duration="600ms"><?php echo wp_kses($settings['title'], true); ?></h2>
                <?php endif; ?>
            </div>
            <div class="row align-items-center">
                <?php
                foreach ($settings['process'] as $proces):
                    $style = isset($proces['process_style']) ? $proces['process_style'] : 'middle';
                    $class = 'xb-work-item';
                    $data_attributes = '';

                    if ($style === 'left') {
                        $class .= ' xb-work-item--left wow fadeInLeft';
                        $data_attributes = 'data-wow-delay="150ms" data-wow-duration="600ms"';
                    } elseif ($style === 'middle') {
                        $class .= ' xb-work-item--middle';
                    } elseif ($style === 'right') {
                        $class .= ' xb-work-item--right wow fadeInRight';
                        $data_attributes = 'data-wow-delay="150ms" data-wow-duration="600ms"';
                    }
                    ?>
                    <div class="col-lg-4 mt-30 d-inline-flex justify-content-center">
                        <div class="<?php echo esc_attr($class); ?> pos-rel" <?php echo $data_attributes; ?>>
                            <div class="xb-item--ineer">
                                <?php if (!empty($proces['icon']['id'])): ?>
                                    <div class="xb-item--icon">
                                        <?php echo wp_get_attachment_image($proces['icon']['id'], 'thumbnail'); ?>
                                    </div>
                                <?php endif; ?>
                                <?php if (!empty($proces['title'])): ?>
                                    <h4 class="xb-item--title"><?php echo esc_html($proces['title']); ?></h4>
                                <?php endif; ?>
                            </div>
                            <?php if (!empty($proces['shape']['id'])): ?>
                                <div class="xb-img">
                                    <?php echo wp_get_attachment_image($proces['shape']['id'], 'full'); ?>
                                </div>
                            <?php endif; ?>
                            <?php if (!empty($proces['number'])): ?>
                                <div class="xb-item--content">
                                    <div class="xb-item--line"><img src="<?php echo $line_icon; ?>" alt=""></div>
                                    <span class="xb-item--number"><?php echo esc_html($proces['number']); ?></span>
                                </div>
                            <?php endif; ?>
                            <?php if (!empty($proces['arrow']['id'])): ?>
                                <div class="xb-item--arrow"><?php echo wp_get_attachment_image($proces['arrow']['id'], 'full'); ?></div>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Process_V3());