<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Roadmap extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-roadmap';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Roadmap', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'sub_title_icon',
            [
                'label' => esc_html__('Sub Title Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'show_nav',
            [
                'label' => esc_html__('Show Slider Arrow', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Roadmap', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'ques',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Ques Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'year',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Year', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Roadmap', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->add_control(
            'show_pagination_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'show_pagination',
            [
                'label' => esc_html__('Show Pagination', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'shape_option_hr',
            [
                'label' => esc_html__('Shape Option', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'shape1',
            [
                'label' => esc_html__('Shape 1', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape2',
            [
                'label' => esc_html__('Shape 2', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape3',
            [
                'label' => esc_html__('Shape 2', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'subtitle-c',
            [
                'label' => esc_html__('Sub Title Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title--strock' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title--strock',
            ]
        );
        $this->add_control(
            'title_color_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .title',
            ]
        );
        $this->add_control(
            'nav_style_hr',
            [
                'label' => esc_html__('Nav Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'textdomain'),
            ]
        );

        $this->add_control(
            'nav_bg-c',
            [
                'label' => esc_html__('Nav Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_border-c',
            [
                'label' => esc_html__('Nav Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'textdomain'),
            ]
        );

        $this->add_control(
            'hnav_bg-c',
            [
                'label' => esc_html__('Nav Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hnav_border-c',
            [
                'label' => esc_html__('Nav Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hnav-c',
            [
                'label' => esc_html__('Nav Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-button .sa-swiper-btn:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'roadmap_style',
            [
                'label' => esc_html__('Roadmap', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'roadmap-bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'roadmap_padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'ques_color_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'ques_text-c',
            [
                'label' => esc_html__('Ques Text Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item .xb-item--ques' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ques_text_typography',
                'selector' => '{{WRAPPER}} .roadmap-item .xb-item--ques',
            ]
        );
        $this->add_control(
            'year_color_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'year_text-c',
            [
                'label' => esc_html__('Year Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item .xb-item--year' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'year_bg-c',
            [
                'label' => esc_html__('Year BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item .xb-item--year' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'year_text_typography',
                'selector' => '{{WRAPPER}} .roadmap-item .xb-item--year',
            ]
        );
        $this->add_control(
            'rm_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'rm_title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rm_title_typography',
                'selector' => '{{WRAPPER}} .roadmap-item .xb-item--title',
            ]
        );
        $this->add_control(
            'rm_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'rm_content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .roadmap-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rm_content_typography',
                'selector' => '{{WRAPPER}} .roadmap-item .xb-item--content',
            ]
        );
        $this->add_control(
            'pagination_style_hr',
            [
                'label' => esc_html__('Pagination Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'pagination-c',
            [
                'label' => esc_html__('Pagination Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .raodmap-slider .swiper-pagination .swiper-pagination-bullet' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $line_left = INNOMAX_DIR_URL . 'assets/img/line-left.png';
        $line_right = INNOMAX_DIR_URL . 'assets/img/line-right.png';
        ?>
        <section class="roadmap roadmap-pb pt-130 pb-200 pos-rel" data-bg-color="#0F55DC">
            <div class="container">
                <div class="sa-tes_top roadmap-top pos-rel mb-85">
                    <div class="sec-title--two">
                        <?php if (!empty($settings['sub_title'])): ?>
                            <div class="sub-title sub-title--strock wow fadeInDown" data-wow-duration="600ms">
                                <?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail');
                                echo esc_html($settings['sub_title']); ?>
                            </div>
                        <?php endif; ?>
                        <div class="clearfix"></div>
                        <?php if (!empty($settings['title'])): ?>
                            <h2 class="title clr-white wow fadeInDown" data-wow-delay="150ms" data-wow-duration="600ms">
                                <?php echo esc_html($settings['title']); ?></h2>
                        <?php endif; ?>
                    </div>
                    <?php if ('yes' === $settings['show_nav']): ?>
                        <div class="sa-tes_button roadmap-button">
                            <div class="sa-swiper-btn swiper-button-prev"><i class="fal fa-angle-left"></i></div>
                            <div class="sa-swiper-btn active swiper-button-next"><i class="fal fa-angle-right"></i>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
            <div class="raodmap-slider">
                <div class="swiper-wrapper">
                    <?php
                    foreach ($settings['lists'] as $list):
                        ?>
                        <div class="swiper-slide">
                            <div class="roadmap-item">
                                <?php if (!empty($list['ques'])): ?>
                                    <div class="xb-item--top">
                                        <img src="<?php echo esc_url($line_left); ?>" alt="">
                                        <span class="xb-item--ques"><?php echo esc_html($list['ques']); ?></span>
                                        <img src="<?php echo esc_url($line_right); ?>" alt="">
                                    </div>
                                <?php endif; ?>
                                <div class="xb-item--holder">
                                    <?php if (!empty($list['year'])): ?>
                                        <span class="xb-item--year"><?php echo esc_html($list['year']); ?></span>
                                    <?php endif; ?>
                                    <?php if (!empty($list['title'])): ?>
                                        <h3 class="xb-item--title"><?php echo esc_html($list['title']); ?></h3>
                                    <?php endif; ?>
                                    <?php if (!empty($list['content'])): ?>
                                        <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
                <?php if ('yes' === $settings['show_pagination']): ?>
                    <div class="swiper-pagination"></div>
                <?php endif; ?>
            </div>
            <div class="roadmap-shape">
                <?php if (!empty($settings['shape1']['id'])): ?>
                    <div class="shape shape--one"><?php echo wp_get_attachment_image($settings['shape1']['id'], 'full'); ?></div>
                <?php endif; ?>
                <?php if (!empty($settings['shape2']['id'])): ?>
                    <div class="shape shape--two"><?php echo wp_get_attachment_image($settings['shape2']['id'], 'full'); ?></div>
                <?php endif; ?>
                <?php if (!empty($settings['shape3']['id'])): ?>
                    <div class="shape shape--three"><?php echo wp_get_attachment_image($settings['shape3']['id'], 'full'); ?></div>
                <?php endif; ?>
            </div>
        </section>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Roadmap());