<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Section_Title extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-sec-title';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Section Title', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label' => __('Design Style', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __('Style 1', 'innomax-core'),
                    'style_2' => __('Style 2', 'innomax-core'),
                    'style_3' => __('Style 3', 'innomax-core'),
                    'style_4' => __('Style 4', 'innomax-core'),
                    'style_5' => __('Style 5', 'innomax-core'),
                    'style_6' => __('Style 6', 'innomax-core'),
                    'style_7' => __('Style 7', 'innomax-core'),
                    'style_8' => __('Style 8', 'innomax-core'),
                ],
                'default' => 'style_1',
            ]
        );
        $this->add_control(
            'sub_title_icon',
            [
                'label' => esc_html__('Sub Title Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'design_style' => ['style_1', 'style_2', 'style_3', 'style_4', 'style_5', 'style_7', 'style_8'],
                ],
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'condition' => [
                    'design_style' => ['style_1', 'style_2', 'style_3', 'style_4', 'style_5', 'style_7', 'style_8'],
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'condition' => [
                    'design_style' => ['style_4', 'style_6', 'style_8'],
                ],
            ]
        );
        $this->add_control(
            'content', [
                'label' => esc_html__('Content', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'condition' => [
                    'design_style' => ['style_4', 'style_6', 'style_8'],
                ],
            ]
        );
        $this->add_responsive_control(
            'text_align',
            [
                'label' => esc_html__('Text Align', 'innomax-core'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'start' => [
                        'title' => __('Left', 'innomax-core'),
                        'icon' => 'eicon-text-align-left',
                    ],

                    'center' => [
                        'title' => __('Center', 'innomax-core'),
                        'icon' => 'eicon-text-align-center',
                    ],

                    'end' => [
                        'title' => __('Right', 'innomax-core'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .da-sec-titlte' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .sec-title--five' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'sub_title-c',
            [
                'label' => esc_html__('Sub Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .da-sec-titlte .sub_title' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_1', 'style_2', 'style_4', 'style_7', 'style_8'],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'subtitle_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sec-title--three .sub-title span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
                'condition' => [
                    'design_style' => ['style_5'],
                ],
            ]
        );
        $this->add_control(
            'sub_title_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-sec-titlte .sub_title' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .sec-title--three .sub-title' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_4', 'style_5'],
                ],
            ]
        );
        $this->add_control(
            'subtitle_bg-c',
            [
                'label' => esc_html__('Subtitle BG Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'background-color: {{VALUE}} !important',
                ],
                'condition' => [
                    'design_style' => ['style_1', 'style_2', 'style_7', 'style_8'],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title, {{WRAPPER}} .da-sec-titlte .sub_title',
                'condition' => [
                    'design_style' => ['style_1', 'style_2', 'style_4', 'style_5', 'style_7', 'style_8'],
                ],
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .da-sec-titlte .title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .sec-title--five .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .title, {{WRAPPER}} .da-sec-titlte .title, {{WRAPPER}} .sec-title--five .title',
            ]
        );
        $this->add_control(
            'title_padding',
            [
                'label' => esc_html__('Title Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .da-sec-titlte .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .sec-title--five .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' => esc_html__('Title Margin', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .da-sec-titlte .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .sec-title--five .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'content_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-sec-titlte .content' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .sec-title--five .content' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .sec-title--four p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .da-sec-titlte .content, {{WRAPPER}} .sec-title--five .content, {{WRAPPER}} .sec-title--four p',
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <?php if ($settings['design_style'] === 'style_2'): ?>
        <div class="sec-title--two">
            <div class="sub-title sub-title--strock wow fadeInDown" data-wow-duration="600ms">
                <?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail');
                echo esc_html($settings['sub_title']) ?>
            </div>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title clr-white wow fadeInDown" data-wow-delay="150ms"
                    data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_3'): ?>
        <div class="sec-title--two text-center mb-60">
            <?php if (!empty($settings['sub_title'])): ?>
                <span class="sub-title wow fadeInDown" data-wow-duration="600ms">
                    <?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail');
                    echo esc_html($settings['sub_title']); ?>
                </span>
            <?php endif; ?>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow fadeInDown" data-wow-delay="150ms"
                    data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_4'): ?>
        <div class="da-sec-titlte">
            <?php if (!empty($settings['sub_title'])): ?>
                <span class="sub_title"><span><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?></span><?php echo esc_html($settings['sub_title']) ?></span>
            <?php endif; ?>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title"><?php echo wp_kses($settings['title'], true); ?></h2>
            <?php endif; ?>
            <?php if (!empty($settings['content'])): ?>
                <p class="content"><?php echo wp_kses($settings['content'], true); ?></p>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_5'): ?>
        <div class="sec-title--two sec-title--three">
            <?php if (!empty($settings['sub_title'])): ?>
                <span class="sub-title wow fadeInDown"
                      data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><span><?php echo esc_html($settings['sub_title']) ?></span></span>
            <?php endif; ?>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow fadeInDown"
                    data-wow-duration="600ms"><?php echo wp_kses($settings['title'], true); ?></h2>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_6'): ?>
        <div class="sec-title--five">
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow fadeInUp"
                    data-wow-duration="600ms"><?php echo wp_kses($settings['title'], true); ?></h2>
            <?php endif; ?>
            <?php if (!empty($settings['content'])): ?>
                <p class="content wow fadeInUp" data-wow-delay="150ms"
                   data-wow-duration="600ms"><?php echo wp_kses($settings['content'], true); ?></p>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_7'): ?>
        <div class="sec-title--two sec-title--four">
            <?php if (!empty($settings['sub_title'])): ?>
                <div class="sub-title wow fadeInDown"
                     data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><?php echo wp_kses($settings['sub_title'], true); ?></div>
            <?php endif; ?>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow fadeInDown" data-wow-delay="150ms"
                    data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
            <?php endif; ?>
        </div>
    <?php elseif ($settings['design_style'] === 'style_8'): ?>
        <div class="sec-title--two sec-title--four">
            <?php if (!empty($settings['sub_title'])): ?>
                <div class="sub-title wow fadeInDown" data-wow-delay="150ms"
                     data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><?php echo wp_kses($settings['sub_title'], true); ?></div>
            <?php endif; ?>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow skewIn"
                    data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
            <?php endif; ?>
            <?php if (!empty($settings['content'])): ?>
                <p><?php echo wp_kses($settings['content'], true); ?></p>
            <?php endif; ?>
        </div>
    <?php else: ?>
        <div class="sec-title--two">
            <?php if (!empty($settings['sub_title'])): ?>
                <span class="sub-title wow fadeInDown" data-wow-duration="600ms">
                    <?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail');
                    echo esc_html($settings['sub_title']) ?>
                </span>
            <?php endif; ?>
            <div class="clearfix"></div>
            <?php if (!empty($settings['title'])): ?>
                <h2 class="title wow skewIn" data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
            <?php endif; ?>
        </div>
    <?php
    endif;
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Section_Title());