<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Service_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-service-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Service V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'active',
            [
                'label' => esc_html__('Active', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textarea'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'services',
            [
                'label' => esc_html__('Add Service', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'content_style_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-content-list .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .service-content-list .title',
            ]
        );
        $this->add_control(
            'service_style_hr',
            [
                'label' => esc_html__('Service Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'service_bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-content-box' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'service_padding',
            [
                'label' => esc_html__('Box Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .service-content-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            's_title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            's_title_active-c',
            [
                'label' => esc_html__('Title Active Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item.current .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_active_bg-c',
            [
                'label' => esc_html__('Title Active BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list .active-bg' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'icon_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'icon-c',
            [
                'label' => esc_html__('Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item .xb-item--icon svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'icon-bg-c',
            [
                'label' => esc_html__('Icon Background Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item .xb-item--icon' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'arrow_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'arrow-c',
            [
                'label' => esc_html__('Arrow Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item .xb-item--arrow svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'arrow-active-c',
            [
                'label' => esc_html__('Arrow Active Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item.current .xb-item--arrow svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'arrow-bg-c',
            [
                'label' => esc_html__('Arrow Background Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item .xb-item--arrow' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'arrow-bg-active-c',
            [
                'label' => esc_html__('Arrow Active Background Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-list-item.current .xb-item--arrow' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="services z-1 service-height pos-rel">
            <div class="service-images">
                <?php
                foreach ($settings['services'] as $service):
                    ?>
                    <div class="service-image-item <?php if ('yes' == $service['active']) {
                        echo esc_attr('active');
                    } ?>" <?php if (!empty($service['image']['url'])): ?>
                         style="background-image: url('<?php echo esc_url($service['image']['url']); ?>') <?php endif; ?>"></div>
                <?php endforeach; ?>
            </div>
            <div class="service-content-box ul_li pos-rel">
                <div class="service-content-list">
                    <?php if (!empty($settings['title'])): ?>
                        <h3 class="title">Core expertise</h3>
                    <?php endif; ?>
                    <div class="service-list">
                        <?php
                        foreach ($settings['services'] as $service):
                            ?>
                            <div class="service-list-item ul_li_between <?php if ('yes' == $service['active']) {
                                echo esc_attr('current');
                            } ?>">
                                <div class="xb-item--icon">
                                    <?php \Elementor\Icons_Manager::render_icon($service['icon'], ['aria-hidden' => 'true']); ?>
                                </div>
                                <?php if (!empty($service['title'])): ?>
                                    <h3 class="xb-item--title"><?php echo esc_html($service['title']); ?></h3>
                                <?php endif; ?>
                                <div class="xb-item--arrow">
                                    <svg width="12" height="12" viewBox="0 0 12 12" fill="none"
                                         xmlns="http://www.w3.org/2000/svg">
                                        <path d="M12 1C12 0.447714 11.5523 -7.61451e-07 11 -3.39982e-07L2 -2.13542e-07C1.44772 -5.50717e-07 1 0.447715 1 0.999999C1 1.55228 1.44772 2 2 2L10 2L10 10C10 10.5523 10.4477 11 11 11C11.5523 11 12 10.5523 12 10L12 1ZM1.70711 11.7071L11.7071 1.70711L10.2929 0.292893L0.292893 10.2929L1.70711 11.7071Z"
                                              fill="#111112"/>
                                    </svg>
                                </div>
                            </div>
                        <?php endforeach; ?>
                        <div class="active-bg"></div>
                    </div>
                </div>
                <div class="service-content-image">
                    <?php
                    foreach ($settings['services'] as $service):
                        ?>
                        <div class="xb-item--img <?php if ('yes' == $service['active']) {
                            echo esc_attr('active');
                        } ?>" <?php if (!empty($service['image']['url'])): ?>
                             style="background-image: url('<?php echo esc_url($service['image']['url']); ?>') <?php endif; ?>"></div>
                    <?php endforeach; ?>
                </div>
            </div>
        </section>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Service_V2());