<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Service_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-service-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Service V4', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'service_option',
            [
                'label' => esc_html__('Service', 'techco-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Service', 'techco-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('List Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add List', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Service using Elementor. You can find it under <a href="%s" target="_blank">Services</a>.', 'techco-core'),
                        admin_url('edit.php?post_type=techco_service')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .border-bg1 svg rect' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbg-c',
            [
                'label' => esc_html__('Background Hover Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .border-bg2 svg rect' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .cs-service-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'icon_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'icon_bg_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-service-item .xb-item--icon::before',
                'fields_options' => [
                    'background' => [
                        'label' => 'Icon BG Color'
                    ],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'hicon_bg_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-service-item:hover .xb-item--icon::before',
                'fields_options' => [
                    'background' => [
                        'label' => 'Icon Hover BG Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'icon-c',
            [
                'label' => esc_html__('Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-service-item .xb-item--icon svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-service-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .cs-service-item .xb-item--title',
            ]
        );
        $this->add_control(
            'list_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'list-c',
            [
                'label' => esc_html__('List Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-service-item .xb-item--item li' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .cs-service-item .xb-item--item li svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'list_typography',
                'selector' => '{{WRAPPER}} .cs-service-item .xb-item--item li',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $unique_id = isset($settings['_id']) ? esc_attr($settings['_id']) : uniqid('elementor_');
        if (isset($settings['template']) && !empty($settings['template'])) {
            $service_post = get_post($settings['template']);

            if ($service_post instanceof \WP_Post) {
                $service_title = esc_html($service_post->post_title);
                $service_permalink = esc_url(get_permalink($service_post));
                ?>

                <div class="cs-service-item">
                    <div class="xb-item--inner">
                        <div class="xb-item--icon">
                            <?php \Elementor\Icons_Manager::render_icon($settings['icon'], ['aria-hidden' => 'true']); ?>
                        </div>
                        <h3 class="xb-item--title"><?php echo $service_title; ?></h3>
                        <ul class="xb-item--item list-unstyled">
                            <?php
                            foreach ($settings['lists'] as $list):
                                ?>
                                <li><?php \Elementor\Icons_Manager::render_icon($list['icon'], ['aria-hidden' => 'true']); echo wp_kses($list['text'], true); ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                    <div class="border-bg1">
                        <svg width="410" height="360" viewBox="0 0 410 360" fill="none" preserveAspectRatio="none"
                             xmlns="http://www.w3.org/2000/svg">
                            <rect width="410" height="360" rx="15" fill="#010315"/>
                            <rect x="0.5" y="0.5" width="409" height="359" rx="14.5"
                                  fill="url(#paint0_radial_1685_8961_<?php echo $unique_id; ?>)" stroke="#23263C"/>
                            <rect opacity="0.5" x="63" width="190" height="1"
                                  fill="url(#paint1_radial_1685_896345_<?php echo $unique_id; ?>)"/>
                            <defs>
                                <radialGradient id="paint0_radial_1685_8961_<?php echo $unique_id; ?>" cx="0" cy="0"
                                                r="1"
                                                gradientUnits="userSpaceOnUse"
                                                gradientTransform="translate(205) scale(288.23 306.36)">
                                    <stop offset="0" stop-color="white" stop-opacity="0.05"/>
                                    <stop offset="1" stop-color="#050014" stop-opacity="0"/>
                                </radialGradient>
                                <radialGradient id="paint1_radial_1685_896345_<?php echo $unique_id; ?>" cx="0" cy="0"
                                                r="1"
                                                gradientUnits="userSpaceOnUse"
                                                gradientTransform="translate(158 0.5) scale(95 0.5)">
                                    <stop offset="0" stop-color="white"/>
                                    <stop offset="1" stop-color="white" stop-opacity="0"/>
                                </radialGradient>
                            </defs>
                        </svg>
                    </div>
                    <div class="border-bg2">
                        <svg width="410" height="360" viewBox="0 0 410 360" fill="none" preserveAspectRatio="none"
                             xmlns="http://www.w3.org/2000/svg">
                            <rect width="410" height="360" rx="15" fill="#010315"/>
                            <rect x="0.5" y="0.5" width="409" height="359" rx="14.5"
                                  fill="url(#paint0_radial_1685_8952_<?php echo $unique_id; ?>)"
                                  stroke="url(#paint1_linear_1685_895_<?php echo $unique_id; ?>)"/>
                            <rect opacity="0.5" x="63" width="190" height="1"
                                  fill="url(#paint2_radial_1685_8951_<?php echo $unique_id; ?>)"/>
                            <defs>
                                <radialGradient id="paint0_radial_1685_8952_<?php echo $unique_id; ?>" cx="0" cy="0"
                                                r="1"
                                                gradientUnits="userSpaceOnUse"
                                                gradientTransform="translate(205) scale(288.23 306.36)">
                                    <stop offset="0" stop-color="white" stop-opacity="0.05"/>
                                    <stop offset="1" stop-color="#050014" stop-opacity="0"/>
                                </radialGradient>
                                <linearGradient id="paint1_linear_1685_895_<?php echo $unique_id; ?>" x1="410"
                                                y1="369.333" x2="221.101"
                                                y2="288.747" gradientUnits="userSpaceOnUse">
                                    <stop offset="0" stop-color="#6780D2"/>
                                    <stop offset="1" stop-color="#2F3B8D"/>
                                </linearGradient>
                                <radialGradient id="paint2_radial_1685_8951_<?php echo $unique_id; ?>" cx="0" cy="0"
                                                r="1"
                                                gradientUnits="userSpaceOnUse"
                                                gradientTransform="translate(158 0.5) scale(95 0.5)">
                                    <stop offset="0" stop-color="white"/>
                                    <stop offset="1" stop-color="white" stop-opacity="0"/>
                                </radialGradient>
                            </defs>
                        </svg>
                    </div>
                    <a href="<?php echo $service_permalink; ?>" class="xb-overlay xb-overlay-link"></a>
                </div>
                <?php
            }
        }
    }


    protected function template_select()
    {
        $type = 'innomax_service';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'innomax-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Service_V4());