<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Team_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-team-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Team V3', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'experience_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Experience Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'rating_number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Rating Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'avatar',
            [
                'label' => esc_html__('Avatar', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'desig',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Designation', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'social_option',
            [
                'label' => esc_html__('Social Option', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'linkedin',
            [
                'label' => esc_html__('Linkedin URL', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'twitter_x',
            [
                'label' => esc_html__('Twitter X URL', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'teams',
            [
                'label' => esc_html__('Add Team Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'border-c',
            [
                'label' => esc_html__('Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .team-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'experience_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'experience_title-c',
            [
                'label' => esc_html__('Experience Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--skill' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'experience_title_typography',
                'selector' => '{{WRAPPER}} .team-item .xb-item--skill',
            ]
        );
        $this->add_control(
            'rating_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'rating_number-c',
            [
                'label' => esc_html__('Rating Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--reating' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'rating_number_bg-c',
            [
                'label' => esc_html__('Rating BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--reating' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'rating_padding',
            [
                'label' => esc_html__('Rating Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--reating' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rating_typography',
                'selector' => '{{WRAPPER}} .team-item .xb-item--reating',
            ]
        );
        $this->add_control(
            'avatar_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'avatar-c',
            [
                'label' => esc_html__('Avatar Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--avatar' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'name_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Name Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .team-item .xb-item--name',
            ]
        );
        $this->add_control(
            'social_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'social-c',
            [
                'label' => esc_html__('Social Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--social-link li a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .team-item .xb-item--social-link li a svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'social_hover-c',
            [
                'label' => esc_html__('Social Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-item .xb-item--social-link li a:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .team-item .xb-item--social-link li a:hover svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="innomax-team">
            <div class="row mt-none-30">
                <?php
                foreach ($settings['teams'] as $team):
                    ?>
                    <div class="col-xl-4 col-lg-6 col-md-6 mt-30">
                        <div class="team-item">
                            <div class="xb-item--content pos-rel">
                                <?php if (!empty($team['image']['id'])): ?>
                                    <div class="xb-item--img">
                                        <?php echo wp_get_attachment_image($team['image']['id'], 'full'); ?>
                                    </div>
                                <?php endif; ?>
                                <div class="xb-item--item">
                                    <?php if (!empty($team['experience_title'])): ?>
                                        <span class="xb-item--skill"><?php echo esc_html($team['experience_title']); ?></span>
                                    <?php endif; ?>
                                    <?php if (!empty($team['rating_number'])): ?>
                                        <span class="xb-item--reating"><i
                                                    class="fas fa-star"></i> <?php echo esc_html($team['rating_number']); ?></span>
                                    <?php endif; ?>
                                </div>
                            </div>
                            <div class="xb-item--inner ul_li_between align-items-end">
                                <div class="xb-item--holder">
                                    <?php if (!empty($team['avatar'])): ?>
                                        <div class="xb-item--avatar">
                                            <?php echo wp_get_attachment_image($team['avatar']['id'], 'medium'); ?>
                                        </div>
                                    <?php endif; ?>
                                    <div class="xb-item--author">
                                        <?php if (!empty($team['name'])): ?>
                                            <h3 class="xb-item--name"><?php echo esc_html($team['name']); ?></h3>
                                        <?php endif; ?>
                                        <?php if (!empty($team['desig'])): ?>
                                            <span class="xb-item--desig"><?php echo esc_html($team['desig']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <ul class="xb-item--social-link ul_li">
                                    <?php if (!empty($team['linkedin']['url'])): ?>
                                        <li><a href="<?php echo esc_url($team['linkedin']['url']); ?>"><i
                                                        class="fab fa-linkedin-in"></i></a></li>
                                    <?php endif; ?>
                                    <?php if (!empty($team['twitter_x']['url'])): ?>
                                        <li><a href="<?php echo esc_url($team['twitter_x']['url']); ?>">
                                                <svg width="18" height="18" viewBox="0 0 18 18" fill="none"
                                                     xmlns="http://www.w3.org/2000/svg">
                                                    <path d="M10.6883 7.62176L17.2244 0H15.6756L10.0002 6.61789L5.46738 0H0.239258L7.09382 10.0074L0.239258 18H1.7882L7.7815 11.0113L12.5685 18H17.7967L10.6879 7.62176H10.6883ZM2.3463 1.16972H4.72537L15.6763 16.8835H13.2972L2.3463 1.16972Z"
                                                          fill="#111112"/>
                                                </svg>
                                            </a></li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Innomax_Team_V3());