<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Testimonial_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-testimonial-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Testimonial V2', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'testimonial_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'avatar',
            [
                'label' => esc_html__('Avatar', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'desig',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Designation', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'rating_img',
            [
                'label' => esc_html__('Rating Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'rating_number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Rating Number', 'textdomain'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'quote',
            [
                'label' => esc_html__('Quote Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Testimonial Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'nav_settings_option',
            [
                'label' => esc_html__('Nav Settings', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'show_nav',
            [
                'label' => esc_html__('Show Nav', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'show_pagination',
            [
                'label' => esc_html__('Show Pagination', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tes-heading .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .tes-heading .title',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'tm_style_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'service_border-c',
            [
                'label' => esc_html__('Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'testimonial_padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'testimonial_icon_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'tm_icon_bg-c',
            [
                'label' => esc_html__('Icon Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .xb-item--author .img--one' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'testimonial_name_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Name Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .testimonial-item .xb-item--name',
            ]
        );
        $this->add_control(
            'testimonial_desig_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'desig-c',
            [
                'label' => esc_html__('Designation Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desig_typography',
                'selector' => '{{WRAPPER}} .testimonial-item .xb-item--desig',
            ]
        );
        $this->add_control(
            'testimonial_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'testimonial_content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_content_typography',
                'selector' => '{{WRAPPER}} .testimonial-item .xb-item--content',
            ]
        );
        $this->add_control(
            'nav_style',
            [
                'label' => esc_html__('Nav Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav_bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-buttons' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_border-c',
            [
                'label' => esc_html__('Nav Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-buttons' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-buttons' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'pagination_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'pagination-c',
            [
                'label' => esc_html__('Pagination BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-pagination' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'pagination-border-c',
            [
                'label' => esc_html__('Pagination Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-pagination' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'pagination-number-c',
            [
                'label' => esc_html__('Pagination Number Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-pagination .swiper-pagination' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="testimonial o-hidden pos-rel pt-125 pb-200 bg_img">
            <?php if (!empty($settings['title'])): ?>
                <div class="tes-heading text-center mb-60">
                    <h2 class="title wow fadeInDown" data-wow-delay="100ms"
                        data-wow-duration="600ms"><?php echo esc_html($settings['title']); ?></h2>
                </div>
            <?php endif; ?>
            <div class="testimonial-slider pb-40">
                <div class="swiper-wrapper">
                    <?php
                    foreach ($settings['lists'] as $list):
                        ?>
                        <div class="swiper-slide">
                            <div class="testimonial-item">
                                <div class="xb-item--holder">
                                    <div class="xb-item--author">
                                        <?php if (!empty($list['icon']['id'])): ?>
                                            <div class="img img--one"><?php echo wp_get_attachment_image($list['icon']['id'], 'thumbnail'); ?></div>
                                        <?php endif; ?>
                                        <?php if (!empty($list['avatar']['id'])): ?>
                                            <div class="img img--two"><?php echo wp_get_attachment_image($list['avatar']['id'], 'thumbnail'); ?></div>
                                        <?php endif; ?>
                                        <div class="xb-item--avatar mt-20">
                                            <?php if (!empty($list['name'])): ?>
                                                <h3 class="xb-item--name"><?php echo esc_html($list['name']); ?></h3>
                                            <?php endif; ?>
                                            <?php if (!empty($list['desig'])): ?>
                                                <span class="xb-item--desig"><?php echo esc_html($list['desig']); ?></span>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <?php if (!empty($list['content'])): ?>
                                        <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                    <?php endif; ?>
                                </div>
                                <div class="xb-item--bottom ul_li_between">
                                    <div class="xb-item--rating">
                                        <span><?php echo wp_get_attachment_image($list['rating_img']['id'], 'medium'); ?><?php echo esc_html($list['rating_number']); ?></span>
                                    </div>
                                    <?php if (!empty($list['quote']['id'])): ?>
                                        <span class="xb-item--quat"><?php echo wp_get_attachment_image($list['quote']['id'], 'thumbnail'); ?></span>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
                <div class="testimonial-pagination">
                    <?php if ('yes' === $settings['show_nav']): ?>
                        <div class="swiper-buttons swiper-button-next"><i class="far fa-angle-right"></i></div>
                        <div class="swiper-buttons swiper-button-prev"><i class="far fa-angle-left"></i></div>
                    <?php endif; ?>
                    <?php if ('yes' === $settings['show_pagination']): ?>
                        <div class="swiper-pagination"></div>
                    <?php endif; ?>
                </div>
            </div>
        </section>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Testimonial_V2());