<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Testimonial_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-testimonial-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Testimonial V3', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'testimonial_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content1',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'left_content_hr',
            [
                'label' => esc_html__('Left Content', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'title1',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'sub_content1',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Sub Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'right_content_hr',
            [
                'label' => esc_html__('Right Content', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater->add_control(
            'title2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'sub_content2',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Sub Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $repeater->add_control(
            'content2',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content Two', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content3',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content Three', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Testimonial Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'nav_settings_option',
            [
                'label' => esc_html__('Nav Settings', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'show_nav',
            [
                'label' => esc_html__('Show Nav', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'textdomain'),
                'label_off' => esc_html__('Hide', 'textdomain'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'tm_style_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'testimonial_padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'testimonial_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-tes-left .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .da-tes-left .xb-item--title',
            ]
        );
        $this->add_control(
            'testimonial_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'testimonial_content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-tes-left .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_content_typography',
                'selector' => '{{WRAPPER}} .da-tes-left .xb-item--content',
            ]
        );
        $this->add_control(
            'm_content_style',
            [
                'label' => esc_html__('Middle Content Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'title2-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-tes-left .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title2_typography',
                'selector' => '{{WRAPPER}} .da-tes-left .xb-item--number',
            ]
        );
        $this->add_control(
            'content2-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-tes-left .xb-item--text' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content2_typography',
                'selector' => '{{WRAPPER}} .da-tes-left .xb-item--text',
            ]
        );

        $this->add_control(
            'nav_style',
            [
                'label' => esc_html__('Nav Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav_bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial-wrap .da-swiper-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_bg_hover-c',
            [
                'label' => esc_html__('Nav BG Hover Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial-wrap .da-swiper-btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial-wrap .da-swiper-btn i' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_hover-c',
            [
                'label' => esc_html__('Nav Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .da-testimonial-wrap .da-swiper-btn:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="da-testimonial-wrap pos-rel">
            <div class="da-testimonial-slider swiper-container">
                <div class="swiper-wrapper">
                    <?php
                    foreach ($settings['lists'] as $list):
                        ?>
                        <div class="swiper-slide da-testimonial">
                            <div class="row align-items-center mt-none-30">
                                <div class="col-lg-6 mt-30">
                                    <div class="da-tes-left">
                                        <?php if (!empty($list['title'])): ?>
                                            <h2 class="xb-item--title"><?php echo wp_kses($list['title'], true); ?></h2>
                                        <?php endif; ?>
                                        <?php if (!empty($list['content1'])): ?>
                                            <p class="xb-item--content content--one"><?php echo wp_kses($list['content1'], true); ?></p>
                                        <?php endif; ?>
                                        <div class="xb-item--holder ul_li align-items-start">
                                            <div class="xb-item--meta">
                                                <?php if (!empty($list['title1'])): ?>
                                                    <h3 class="xb-item--number"><?php echo wp_kses($list['title1'], true); ?></h3>
                                                <?php endif; ?>
                                                <?php if (!empty($list['sub_content1'])): ?>
                                                    <span class="xb-item--text"><?php echo wp_kses($list['sub_content1'], true); ?></span>
                                                <?php endif; ?>
                                            </div>
                                            <div class="xb-item--meta">
                                                <?php if (!empty($list['title2'])): ?>
                                                    <h3 class="xb-item--number"><?php echo wp_kses($list['title2'], true); ?></h3>
                                                <?php endif; ?>
                                                <?php if (!empty($list['sub_content2'])): ?>
                                                    <span class="xb-item--text"><?php echo wp_kses($list['sub_content2'], true); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                        <?php if (!empty($list['content2'])): ?>
                                            <p class="xb-item--content content--two"><?php echo wp_kses($list['content2'], true); ?></p>
                                        <?php endif; ?>
                                        <?php if (!empty($list['content3'])): ?>
                                            <p class="xb-item--content content--three"><?php echo wp_kses($list['content3'], true); ?></p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <div class="col-lg-6 mt-30">
                                    <div class="da-tes-right">
                                        <?php if (!empty($list['image']['id'])): ?>
                                            <div class="xb-item--author">
                                                <?php echo wp_get_attachment_image($list['image']['id'], 'full'); ?>
                                            </div>
                                        <?php endif; ?>
                                        <?php if (!empty($list['logo']['id'])): ?>
                                            <div class="xb-item--avatar">
                                                <?php echo wp_get_attachment_image($list['logo']['id'], 'full'); ?>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
            <?php if ('yes' === $settings['show_nav']): ?>
                <div class="da-swiper-btn swiper-button-prev"><i class="fal fa-long-arrow-left"></i></div>
                <div class="da-swiper-btn swiper-button-next"><i class="fal fa-long-arrow-right"></i></div>
            <?php endif; ?>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Testimonial_V3());