<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Testimonial_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-testimonial-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Testimonial V4', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'sub_title_icon',
            [
                'label' => esc_html__('Sub Title Icon', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            's_title', [
                'label' => esc_html__('Title', 'innomax-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'testimonial_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'subtitle',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'desig',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Designation', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Text', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'number2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number Two', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'text2',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Text Two', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Testimonial Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'subtitle_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sec-title--three .sub-title span',
                'fields_options' => [
                    'background' => [
                        'label' => 'Sub Title Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'sub_title_border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 's_subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title',
            ]
        );
        $this->add_control(
            's_title-c',
            [
                'label' => esc_html__('Title Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 's_title_typography',
                'selector' => '{{WRAPPER}} .sec-title--three .title',
            ]
        );
        $this->add_control(
            'title_padding',
            [
                'label' => esc_html__('Title Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_margin',
            [
                'label' => esc_html__('Title Margin', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title--three .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'tm_style_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'tm_border_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-tes-content',
                'fields_options' => [
                    'background' => [
                        'label' => 'Testimonial Border Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'testimonial_padding',
            [
                'label' => esc_html__('Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-content .cs-testimonial-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'testimonial_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'subtitle-c',
            [
                'label' => esc_html__('Sub Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-left-item .xb-item--sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-left-item .xb-item--sub-title',
            ]
        );
        $this->add_control(
            'title_color_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-left-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-left-item .xb-item--title',
            ]
        );
        $this->add_control(
            'testimonial_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'testimonial_content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_content_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--content',
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Name Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--name',
            ]
        );
        $this->add_control(
            'desig-c',
            [
                'label' => esc_html__('Designation Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desig_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--desig',
            ]
        );
        $this->add_control(
            'm_content_style',
            [
                'label' => esc_html__('Middle Content Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'number-c',
            [
                'label' => esc_html__('Number Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'number_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--number',
            ]
        );
        $this->add_control(
            'text-c',
            [
                'label' => esc_html__('Text Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--text' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'selector' => '{{WRAPPER}} .cs-tes-item .xb-right-item .xb-item--text',
            ]
        );
        $this->add_control(
            'brand_style_hr',
            [
                'label' => esc_html__('Brand Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'brand_border-c',
            [
                'label' => esc_html__('Brand Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-brand-logo::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'brand_border_active_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-brand-logo .brand-items .xb-line',
                'fields_options' => [
                    'background' => [
                        'label' => 'Brand Border Active Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'nav_style',
            [
                'label' => esc_html__('Nav Style', 'textdomain'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cs-testimonial-slider .slick-arrow' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'ban_bg_color',
                'label' => esc_html__('Background', 'xpress-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cs-testimonial-slider .slick-arrow',
                'fields_options' => [
                    'background' => [
                        'label' => 'Nav BG Color'
                    ],
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'image_option',
            [
                'label' => esc_html__('Image Option', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'shape1',
            [
                'label' => esc_html__('Shape One', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape2',
            [
                'label' => esc_html__('Shape Two', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape3',
            [
                'label' => esc_html__('Shape Three', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="testimonial pos-rel z-1">
            <div class="container">
                <div class="cs-tes_wrap">
                    <div class="sec-title--two sec-title--three text-center mb-175">
                        <?php if (!empty($settings['sub_title'])): ?>
                            <span class="sub-title wow fadeInDown"
                                  data-wow-duration="600ms"><?php echo wp_get_attachment_image($settings['sub_title_icon']['id'], 'thumbnail'); ?><span><?php echo esc_html($settings['sub_title']); ?></span></span>
                        <?php endif; ?>
                        <div class="clearfix"></div>
                        <?php if (!empty($settings['s_title'])): ?>
                            <h2 class="title wow fadeInDown"
                                data-wow-duration="600ms"><?php echo wp_kses($settings['s_title'], true); ?></h2>
                        <?php endif; ?>
                    </div>
                    <div class="cs-tes-content">
                        <div class="cs-testimonial-slider">
                            <?php
                            foreach ($settings['lists'] as $list):
                                ?>
                                <div class="cs-tes-item">
                                    <div class="xb-left-item">
                                        <?php if (!empty($list['image']['id'])): ?>
                                            <div class="xb-item--img">
                                                <?php echo wp_get_attachment_image($list['image']['id'], 'full'); ?>
                                            </div>
                                        <?php endif; ?>
                                        <div class="xb-item--header">
                                            <?php if (!empty($list['subtitle'])): ?>
                                                <span class="xb-item--sub-title"><?php echo esc_html($list['subtitle']); ?></span>
                                            <?php endif; ?>
                                            <?php if (!empty($list['logo']['id'])): ?>
                                                <div class="xb-item--logo"><?php echo wp_get_attachment_image($list['logo']['id'], 'medium'); ?></div>
                                            <?php endif; ?>
                                            <?php if (!empty($list['title'])): ?>
                                                <h2 class="xb-item--title"><?php echo esc_html($list['title']); ?></h2>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <div class="xb-right-item">
                                        <?php if (!empty($list['content'])): ?>
                                            <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                        <?php endif; ?>
                                        <div class="xb-item--author">
                                            <?php if (!empty($list['name'])): ?>
                                                <span class="xb-item--name"><?php echo esc_html($list['name']); ?></span>
                                            <?php endif; ?>
                                            <?php if (!empty($list['desig'])): ?>
                                                <span class="xb-item--desig"><?php echo esc_html($list['desig']); ?></span>
                                            <?php endif; ?>
                                        </div>
                                        <div class="xb-item--holder ul_li">
                                            <div class="xb-item--time">
                                                <?php if (!empty($list['number'])): ?>
                                                    <span class="xb-item--number"><?php echo esc_html($list['number']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($list['text'])): ?>
                                                    <p class="xb-item--text"><?php echo wp_kses($list['text'], true); ?></p>
                                                <?php endif; ?>
                                            </div>
                                            <div class="xb-item--time">
                                                <?php if (!empty($list['number2'])): ?>
                                                    <span class="xb-item--number"><?php echo esc_html($list['number2']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($list['text2'])): ?>
                                                    <p class="xb-item--text"><?php echo wp_kses($list['text2'], true); ?></p>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                    <div class="cs-bran-nav">
                        <div class="barnd-logo cs-brand-logo">
                            <div class="cs-testimonial-slider-nav">
                                <?php
                                foreach ($settings['lists'] as $list):
                                    ?>
                                    <div class="brand-items">
                                        <div class="xb-img">
                                            <?php echo wp_get_attachment_image($list['logo']['id'], 'medium'); ?>
                                        </div>
                                        <div class="xb-line"></div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="cs-tes-shape">
                <?php if (!empty($settings['shape1']['id'])): ?>
                    <div class="shape shape--one"><?php echo wp_get_attachment_image($settings['shape1']['id'], 'full'); ?></div>
                <?php endif; ?>
                <?php if (!empty($settings['shape2']['id'])): ?>
                    <div class="shape shape--two"><?php echo wp_get_attachment_image($settings['shape2']['id'], 'full', false, array('class' => 'world')); ?></div>
                <?php endif; ?>
                <?php if (!empty($settings['shape3']['id'])): ?>
                    <div class="shape shape--three"><?php echo wp_get_attachment_image($settings['shape3']['id'], 'full'); ?></div>
                <?php endif; ?>
            </div>
        </section>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Testimonial_V4());