<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Testimonial extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-testimonial';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Testimonial', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'subtitle_icon',
            [
                'label' => esc_html__('Subtitle Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'subtitle',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'testimonial_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'quote',
            [
                'label' => esc_html__('Quote Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'avatar',
            [
                'label' => esc_html__('Avatar', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'desig',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Designation', 'textdomain'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'logo',
            [
                'label' => esc_html__('Logo', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Testimonial Item', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'image_option',
            [
                'label' => esc_html__('Image Option', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'subtitle-c',
            [
                'label' => esc_html__('Sub Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'subtitle_bg-c',
            [
                'label' => esc_html__('Sub Title BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .sub-title' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .sub-title',
            ]
        );
        $this->add_control(
            'sc_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title--two .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .sec-title--two .title',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'tm_style_option',
            [
                'label' => esc_html__('Testimonial', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item .xb-item--inner' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'service_border-c',
            [
                'label' => esc_html__('Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .sa-testimonial-slider .sa-testimonial-item' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .sa-testimonial-item::before',
                'fields_options' => [
                    'background' => [
                        'label' => 'Border Hover Color'
                    ],
                ],
            ]
        );
        $this->add_control(
            'border_padding',
            [
                'label' => esc_html__('Border Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'testimonial_padding',
            [
                'label' => esc_html__('Testimonial Padding', 'textdomain'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item .xb-item--inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'testimonial_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'testimonial_content-c',
            [
                'label' => esc_html__('Content Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_content_typography',
                'selector' => '{{WRAPPER}} .sa-testimonial-item .xb-item--content',
            ]
        );
        $this->add_control(
            'testimonial_name-c',
            [
                'label' => esc_html__('Name Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_name_typography',
                'selector' => '{{WRAPPER}} .sa-testimonial-item .xb-item--name',
            ]
        );
        $this->add_control(
            'testimonial_desig-c',
            [
                'label' => esc_html__('Designation Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-testimonial-item .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'testimonial_desig_typography',
                'selector' => '{{WRAPPER}} .sa-testimonial-item .xb-item--desig',
            ]
        );
        $this->add_control(
            'tm_arrow_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'tm_arrow_bg-c',
            [
                'label' => esc_html__('Arrow Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tm_arrow_hover_bg-c',
            [
                'label' => esc_html__('Arrow Hover Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tm_arrow-c',
            [
                'label' => esc_html__('Arrow Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tm_arrow_hover-c',
            [
                'label' => esc_html__('Arrow Hover Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'tm_arrow_border-c',
            [
                'label' => esc_html__('Arrow Border Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tm_arrow_border_hover-c',
            [
                'label' => esc_html__('Arrow Border Hover Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sa-tes_button .sa-swiper-btn:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="testimonial o-hidden pb-140">
            <div class="container">
                <div class="sa-tes_top pos-rel mb-60">
                    <div class="sec-title--two">
                        <?php if (!empty($settings['subtitle'])): ?>
                            <div class="sub-title wow fadeInDown" data-wow-duration="600ms">
                                <?php echo wp_get_attachment_image($settings['subtitle_icon']['id'], 'thumbnail'); ?>
                                <?php echo wp_kses($settings['subtitle'], true); ?>
                            </div>
                        <?php endif; ?>
                        <div class="clearfix"></div>
                        <?php if (!empty($settings['title'])): ?>
                            <h2 class="title wow skewIn" data-wow-delay="150ms"
                                data-wow-duration="600ms"><?php echo wp_kses($settings['title'], true); ?></h2>
                        <?php endif; ?>
                    </div>
                    <div class="sa-tes_button">
                        <div class="sa-swiper-btn swiper-button-prev"><i class="fal fa-angle-left"></i></div>
                        <div class="sa-swiper-btn active swiper-button-next"><i class="fal fa-angle-right"></i>
                        </div>
                    </div>
                </div>
            </div>
            <div class="sa-testimonial-slider-inner">
                <div class="sa-testimonial-slider">
                    <div class="swiper-wrapper">
                        <?php
                        foreach ($settings['lists'] as $list):
                            ?>
                            <div class="swiper-slide">
                                <div class="sa-testimonial-item">
                                    <div class="xb-item--inner">
                                        <?php if (!empty($list['quote']['id'])): ?>
                                            <div class="xb-item--quta">
                                                <?php echo wp_get_attachment_image($list['quote']['id'], 'full'); ?>
                                            </div>
                                        <?php endif; ?>
                                        <?php if (!empty($list['content'])): ?>
                                            <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                        <?php endif; ?>
                                        <div class="xb-item--holder ul_li">
                                            <?php if (!empty($list['avatar']['id'])): ?>
                                                <div class="xb-item--avatar">
                                                    <?php echo wp_get_attachment_image($list['avatar']['id'], 'medium'); ?>
                                                </div>
                                            <?php endif; ?>
                                            <div class="xb-item--author">
                                                <?php if (!empty($list['name'])): ?>
                                                    <h3 class="xb-item--name"><?php echo esc_html($list['name']); ?></h3>
                                                <?php endif; ?>
                                                <?php if (!empty($list['desig'])): ?>
                                                    <span class="xb-item--desig"><?php echo esc_html($list['desig']); ?></span>
                                                <?php endif; ?>
                                                <?php if (!empty($list['logo']['id'])): ?>
                                                    <div class="xb-item--logo">
                                                        <?php echo wp_get_attachment_image($list['logo']['id'], 'medium'); ?>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Testimonial());