<?php

/**
 * Elementor Single Widget
 * @package innomax-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Innomax_Button extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-button';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Button', 'innomax-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'innomax-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['innomax_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'btn_option',
            [
                'label' => esc_html__('Button', 'innomax-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label' => __('Design Style', 'innomax-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __('Style 1', 'innomax-core'),
                    'style_2' => __('Style 2', 'innomax-core'),
                    'style_3' => __('Style 3', 'innomax-core'),
                    'style_4' => __('Style 4', 'innomax-core'),
                    'style_5' => __('Style 5', 'innomax-core'),
                    'style_6' => __('Style 6', 'innomax-core'),
                    'style_7' => __('Style 7', 'innomax-core'),
                    'style_8' => __('Style 8', 'innomax-core'),
                ],
                'default' => 'style_1',
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => esc_html__('Button Label', 'innomax-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_responsive_control(
            'text_align',
            [
                'label' => esc_html__('Text Align', 'innomax-core'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,

                'options' => [
                    'start' => [
                        'title' => __('Left', 'innomax-core'),
                        'icon' => 'eicon-text-align-left',
                    ],

                    'center' => [
                        'title' => __('Center', 'innomax-core'),
                        'icon' => 'eicon-text-align-center',
                    ],

                    'end' => [
                        'title' => __('Right', 'innomax-core'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} .xb-btn-wrap' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .xb-btn' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'innomax-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .blc-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'btn_radius',
            [
                'label' => esc_html__('Border Radius', 'innomax-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'design_style!' => ['style_5', 'style_6'],
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_margin_right',
            [
                'label' => esc_html__('Margin Right', 'textdomain'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--data .xb-item--hidden-text' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3'],
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .thm-btn, {{WRAPPER}} .blc-btn',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'innomax-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn--data .xb-item--text' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .blc-btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn--data' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn .btn-shape svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_5', 'style_6'],
                ],
            ]
        );
        $this->add_control(
            'btn_border_color',
            [
                'label' => esc_html__('Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_4'],
                ],
            ]
        );
        $this->add_control(
            'btn_icon-c',
            [
                'label' => esc_html__('Button Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--data .xb-item--icon i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3', 'style_4'],
                ],
            ]
        );
        $this->add_control(
            'btn_icon_bg_c',
            [
                'label' => esc_html__('Button Icon BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--data .xb-item--icon' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3', 'style_4'],
                ],
            ]
        );
        $this->add_control(
            'btn_icon-color',
            [
                'label' => esc_html__('Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--three > span svg path' => 'fill: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_8'],
                ],
            ]
        );
        $this->add_control(
            'btn_icon_bg-c',
            [
                'label' => esc_html__('Icon BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--three > span' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_8'],
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'innomax-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn--data:hover .xb-item--text' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .blc-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color',
            [
                'label' => esc_html__('Background Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn--data:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="0"]' => 'stop-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg_color2',
            [
                'label' => esc_html__('Background Color 2', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blc-btn:hover .btn-shape2 svg stop[offset="1"]' => 'stop-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_5', 'style_6'],
                ],
            ]
        );
        $this->add_control(
            'hbtn_border_color',
            [
                'label' => esc_html__('Border Color', 'innomax-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_4'],
                ],
            ]
        );
        $this->add_control(
            'hbtn_icon-c',
            [
                'label' => esc_html__('Button Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--data:hover .xb-item--icon i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3', 'style_4'],
                ],
            ]
        );
        $this->add_control(
            'hbtn_icon_bg_c',
            [
                'label' => esc_html__('Button Icon BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--data:hover .xb-item--icon' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3', 'style_4'],
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $target = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
        $nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';
        ?>
        <?php if (!empty($settings['design_style']) and $settings['design_style'] == 'style_2'): ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" <?php echo $target . $nofollow; ?>
               class="thm-btn thm-btn--fill_icon thm-btn--data thm-btn--data_blue">
                <div class="xb-item--hidden"><span
                            class="xb-item--hidden-text"><?php echo esc_html($settings['btn_label']); ?></span></div>
                <div class="xb-item--holder">
                    <span class="xb-item--text xb-item--text1"><?php echo esc_html($settings['btn_label']); ?></span>
                    <div class="xb-item--icon"><i class="fal fa-plus"></i></div>
                    <span class="xb-item--text xb-item--text2"><?php echo esc_html($settings['btn_label']); ?></span>
                </div>
            </a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_3'): ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>"
               class="thm-btn thm-btn--fill_icon thm-btn--data">
                <div class="xb-item--hidden"><span
                            class="xb-item--hidden-text"><?php echo esc_html($settings['btn_label']); ?></span></div>
                <div class="xb-item--holder">
                    <span class="xb-item--text xb-item--text1"><?php echo esc_html($settings['btn_label']); ?></span>
                    <div class="xb-item--icon"><i class="fal fa-plus"></i></div>
                    <span class="xb-item--text xb-item--text2"><?php echo esc_html($settings['btn_label']); ?></span>
                </div>
            </a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_4'): ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>"
               class="thm-btn thm-btn--fill_icon thm-btn--data thm-btn--data-strock">
                <div class="xb-item--hidden"><span
                            class="xb-item--hidden-text"><?php echo esc_html($settings['btn_label']); ?></span></div>
                <div class="xb-item--holder">
                    <span class="xb-item--text xb-item--text1"><?php echo esc_html($settings['btn_label']); ?></span>
                    <div class="xb-item--icon"><i class="fal fa-plus"></i></div>
                    <span class="xb-item--text xb-item--text2"><?php echo esc_html($settings['btn_label']); ?></span>
                </div>
            </a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_5'):
        $unique_id = isset($settings['_id']) ? esc_attr($settings['_id']) : uniqid('elementor_');
        ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="blc-btn">
                <span><?php echo esc_html($settings['btn_label']); ?> <i class="far fa-angle-right"></i></span>
                <span class="btn-shape">
                    <svg width="362" height="78" viewBox="0 0 362 78" fill="none" preserveAspectRatio="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0.5 22.7183L25.5093 1.39453H337.972L361.5 22.7092V56.5515L337.98 76.6051H25.5093L0.5 55.2813V22.7183Z"
                              fill="url(#paint0_linear_1600_9966914_<?php echo $unique_id; ?>)" stroke="#23263C"/>
                        <defs>
                          <linearGradient id="paint0_linear_1600_9966914_<?php echo $unique_id; ?>" x1="1.29285"
                                          y1="38.9973" x2="362"
                                          y2="33.9973" gradientUnits="userSpaceOnUse">
                            <stop offset="0" stop-color="#431DAB"/>
                            <stop offset="1" stop-color="#AE6DFE"/>
                          </linearGradient>
                        </defs>
                      </svg>
                </span>
                <span class="btn-shape2">
                    <svg width="271" height="60" viewBox="0 0 271 60" fill="none" preserveAspectRatio="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0.5 17.2308L20.1225 0.5H252.042L270.5 17.2217V43.7692L252.05 59.5H20.1225L0.5 42.7692V17.2308Z"
                              fill="#010315" stroke="url(#paint0_linear_1742_66115_<?php echo $unique_id; ?>)"/>
                        <defs>
                          <linearGradient id="paint0_linear_1742_66115_<?php echo $unique_id; ?>" x1="271" y1="61.5556"
                                          x2="232.791"
                                          y2="-3.08978" gradientUnits="userSpaceOnUse">
                            <stop offset="0" stop-color="#6780D2"/>
                            <stop offset="1" stop-color="#2F3B8D"/>
                          </linearGradient>
                        </defs>
                      </svg>
                </span>
            </a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_6'):
        $unique_id = isset($settings['_id']) ? esc_attr($settings['_id']) : uniqid('elementor_');
        ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" <?php echo $target . $nofollow; ?> class="blc-btn blc-btn--gardiant">
                <span><?php echo esc_html($settings['btn_label']); ?> <i class="far fa-angle-right"></i></span>
                    <span class="btn-shape">
                        <svg width="271" height="60" viewBox="0 0 271 60" fill="none" preserveAspectRatio="none"
                             xmlns="http://www.w3.org/2000/svg">
                            <path d="M0.5 17.2308L20.1225 0.5H252.042L270.5 17.2217V43.7692L252.05 59.5H20.1225L0.5 42.7692V17.2308Z"
                                  fill="#010315" stroke="url(#paint0_linear_1742_66145_<?php echo $unique_id; ?>)"></path>
                            <defs>
                              <linearGradient id="paint0_linear_1742_66145_<?php echo $unique_id; ?>" x1="271" y1="61.5556" x2="232.791"
                                              y2="-3.08978" gradientUnits="userSpaceOnUse">
                                <stop offset="0" stop-color="#6780D2"></stop>
                                <stop offset="1" stop-color="#2F3B8D"></stop>
                              </linearGradient>
                            </defs>
                          </svg>
                    </span>
                    <span class="btn-shape2">
                    <svg width="362" height="78" viewBox="0 0 362 78" fill="none" preserveAspectRatio="none"
                         xmlns="http://www.w3.org/2000/svg">
                        <path d="M0.5 22.7183L25.5093 1.39453H337.972L361.5 22.7092V56.5515L337.98 76.6051H25.5093L0.5 55.2813V22.7183Z"
                              fill="url(#paint0_linear_1600_9966933_<?php echo $unique_id; ?>)" stroke="#23263C"></path>
                        <defs>
                          <linearGradient id="paint0_linear_1600_9966933_<?php echo $unique_id; ?>" x1="1.29285" y1="38.9973" x2="362"
                                          y2="33.9973" gradientUnits="userSpaceOnUse">
                            <stop offset="0" stop-color="#431DAB"></stop>
                            <stop offset="1" stop-color="#AE6DFE"></stop>
                          </linearGradient>
                        </defs>
                      </svg>
                </span>
            </a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_7'):
        ?>
        <div class="xb-btn wow fadeInUp" data-wow-duration="600ms">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="thm-btn thm-btn--devops thm-btn--devops_yellow"><?php echo esc_html($settings['btn_label']); ?></a>
        </div>
    <?php elseif (!empty($settings['design_style']) and $settings['design_style'] == 'style_8'):
        ?>
        <div class="xb-btn wow fadeInUp" data-wow-duration="600ms">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>"
               class="thm-btn thm-btn--three">
                <?php echo esc_html($settings['btn_label']); ?>
                <span>
                    <span class="img--one">
                        <svg width="15" height="16" viewBox="0 0 15 16" fill="none"
                             xmlns="http://www.w3.org/2000/svg">
                          <path d="M14.7071 8.70711C15.0976 8.31658 15.0976 7.68342 14.7071 7.29289L8.34314 0.928931C7.95262 0.538407 7.31946 0.538407 6.92893 0.928932C6.53841 1.31946 6.53841 1.95262 6.92893 2.34315L12.5858 8L6.92893 13.6569C6.53841 14.0474 6.53841 14.6805 6.92893 15.0711C7.31946 15.4616 7.95262 15.4616 8.34315 15.0711L14.7071 8.70711ZM8.74228e-08 9L14 9L14 7L-8.74228e-08 7L8.74228e-08 9Z"
                                fill="#16140C"/>
                        </svg>
                    </span>
                    <span class="img--two">
                        <svg width="15" height="16" viewBox="0 0 15 16" fill="none"
                             xmlns="http://www.w3.org/2000/svg">
                          <path d="M14.7071 8.70711C15.0976 8.31658 15.0976 7.68342 14.7071 7.29289L8.34314 0.928931C7.95262 0.538407 7.31946 0.538407 6.92893 0.928932C6.53841 1.31946 6.53841 1.95262 6.92893 2.34315L12.5858 8L6.92893 13.6569C6.53841 14.0474 6.53841 14.6805 6.92893 15.0711C7.31946 15.4616 7.95262 15.4616 8.34315 15.0711L14.7071 8.70711ZM8.74228e-08 9L14 9L14 7L-8.74228e-08 7L8.74228e-08 9Z"
                                fill="#16140C"/>
                        </svg>
                    </span>
                </span>
            </a>
        </div>
    <?php else: ?>
        <div class="xb-btn-wrap">
            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" <?php echo $target . $nofollow; ?>
               class="thm-btn thm-btn--aso"><?php echo esc_html($settings['btn_label']); ?></a>
        </div>
    <?php
    endif;
    }


}


Plugin::instance()->widgets_manager->register(new Innomax_Button());