<?php
/**
 * The template for displaying 404 pages (not found)
 *
 * @link https://codex.wordpress.org/Creating_an_Error_404_Page
 *
 * @package Innomax
 */

get_header();

$error_banner      = innomax_option('error_banner', true);
$error_banner_title = innomax_option('error_page_title');
$banner_text_align = innomax_option('banner_default_text_align', 'start');
$error_img = innomax_option('error_img');
$not_found_text     = innomax_option('not_found_text');
$enable_breadcrumb = innomax_option('enable_breadcrumb', false);
$go_back_home       = innomax_option('go_back_home', true);

?>

<?php if($error_banner == true) : ?>

    <section class="page-title pt-185 error-page-banner pos-rel bg_img">
        <div class="container">
            <div class="page-title-wrap">
                <div class="row mt-none-30 align-items-end">
                    <div class="col-lg-7 mt-30">
                        <div class="page-title-box text-<?php echo esc_attr($banner_text_align); ?>">
                            <h2 class="title">
                                <?php echo esc_html($error_banner_title); ?>
                            </h2>
                        </div>
                        <?php if (function_exists('bcn_display') && $enable_breadcrumb == true) : ?>
                            <div class="innomax_breadcrumb">
                                <div class="breadcrumb-container">
                                    <?php bcn_display(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php endif; ?>

    <div id="primary" class="content-area pt-120 pb-130">
        <div class="container not-found-content">
            <div class="row justify-content-center">
                <div class="col-lg-12">
                    <div class="contant-wrapper text-center">
                        <div class="text-404">
                            <h2><?php esc_html_e( '404', 'innomax') ?></h2>
                        </div>
                        <div class="error-page__content mb-50">
                            <?php
                            if (!empty($not_found_text)) {
                                echo wp_kses( $not_found_text, array(
                                    'a'      => array(
                                        'href'   => array(),
                                        'target' => array()
                                    ),
                                    'strong' => array(),
                                    'small'  => array(),
                                    'span'   => array(),
                                    'p'   => array(),
                                    'h1'   => array(),
                                    'h2'   => array(),
                                    'h3'   => array(),
                                    'h4'   => array(),
                                    'h5'   => array(),
                                    'h6'   => array(),
                                ) );
                            }else {
                                ?>
                                <h2><?php esc_html_e( 'Hi 👋 Sorry We Can’t Find That Page!', 'innomax') ?></h2>
                                <p><?php esc_html_e( 'Oops! The page you are looking for does not exist. It might have been moved or deleted.', 'innomax') ?></p>
                                <?php
                            }
                            ?>

                            <?php if ($go_back_home == true) : ?>
                                <div class="error-page-button">
                                    <a class="cp-btn" href="<?php echo esc_url(home_url('/')); ?>">
                                        <span class="btn_label"><?php echo esc_html__('Go Back Home', 'innomax') ?></span>
                                        <span class="btn_icon">
                                          <i class="fal fa-arrow-right"></i>
                                        </span>
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div><!-- #primary -->

<?php
get_footer();