<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Innomax
 */

get_header();
$blog_layout = innomax_option('blog_layout', 'right-sidebar');
$enable_banner = innomax_option('blog_banner', true);
$enable_breadcrumb = innomax_option('enable_breadcrumb', false);
$banner_title = innomax_option('blog_title');
$blog_title_sub = innomax_option('blog_title_sub');
$blog_subtitle_img = innomax_option('blog_subtitle_img');
$blog_image = innomax_option('blog_image');
$banner_text_align = innomax_option('banner_default_text_align', 'start');

?>

<?php if ($enable_banner == true) : ?>
    <section class="page-title pt-185 blog-banner pos-rel bg_img">
        <div class="container">
            <div class="page-title-wrap">
                <div class="row mt-none-30 align-items-end">
                    <div class="col-lg-7 mt-30">
                        <div class="page-title-box text-<?php echo esc_attr($banner_text_align); ?>">
                            <?php if (!empty($blog_title_sub)): ?>
                                <span class="sub-title"><img src="<?php echo esc_url($blog_subtitle_img['url']); ?>"
                                                             alt=""> <?php echo esc_html($blog_title_sub); ?></span>
                            <?php endif; ?>
                            <h2 class="title"><?php echo esc_html($banner_title); ?></h2>
                        </div>
                        <?php if (function_exists('bcn_display') && $enable_breadcrumb == true) : ?>
                            <div class="innomax_breadcrumb">
                                <div class="breadcrumb-container">
                                    <?php bcn_display(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    <?php if (!empty($blog_image['image']['url'])): ?>
                        <div class="col-lg-5 mt-30">
                            <div class="sd-right-img pos-rel">
                                <img src="<?php echo esc_url($blog_image['image']['url']); ?>" alt="">
                                <div class="sd-arrow-shape style-2">
                                    <img class="xbzoominzoomup"
                                         src="<?php echo esc_url($blog_image['shape']['url']); ?>" alt="">
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </section>
<?php endif; ?>

    <div id="primary" class="content-area pt-120 pb-130 layout-<?php echo esc_attr($blog_layout); ?>">
        <div class="container">
            <?php
            if ($blog_layout == 'grid') {
                get_template_part('template-parts/post/post-grid');
            } else {
                get_template_part('template-parts/post/post-sidebar');
            }
            ?>
        </div>
        <?php
        $blog_shape = innomax_option('blog_shape', '');
        if (!empty($blog_shape['shape1']['id']) || !empty($blog_shape['shape2']['id']) || !empty($blog_shape['shape3']['id']) || !empty($blog_shape['shape4']['id']) || !empty($blog_shape['shape5']['id'])): ?>
            <div class="blog__shape">
                <div class="shape shape--1">
                    <?php echo wp_get_attachment_image($blog_shape['shape1']['id'], 'full'); ?>
                </div>
                <div class="shape shape--2">
                    <?php echo wp_get_attachment_image($blog_shape['shape2']['id'], 'full'); ?>
                </div>
                <div class="shape shape--3">
                    <?php echo wp_get_attachment_image($blog_shape['shape3']['id'], 'full'); ?>
                </div>
                <div class="shape shape--4">
                    <?php echo wp_get_attachment_image($blog_shape['shape4']['id'], 'full'); ?>
                </div>
                <div class="shape shape--5">
                    <?php echo wp_get_attachment_image($blog_shape['shape5']['id'], 'full'); ?>
                </div>
            </div>
        <?php endif; ?>
    </div><!-- #primary -->


<?php
get_footer();
