<?php
/**
 * The template for displaying all pages
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Borex
 */

get_header();

if (get_post_meta($post->ID, 'innomax_common_meta', true)) {
    $common_meta = get_post_meta($post->ID, 'innomax_common_meta', true);
} else {
    $common_meta = array();
}

if (array_key_exists('layout_meta', $common_meta) && $common_meta['layout_meta'] != 'default') {
    $page_layout = $common_meta['layout_meta'];
} else {
    $page_layout = innomax_option('page_default_layout', 'full-width');
}

if (array_key_exists('sidebar_meta', $common_meta) && $common_meta['sidebar_meta'] != '0') {
    $selected_sidebar = $common_meta['sidebar_meta'];
} else {
    $selected_sidebar = innomax_option('page_default_sidebar', 'sidebar');
}

if ($page_layout == 'left-sidebar' && is_active_sidebar($selected_sidebar) || $page_layout == 'right-sidebar' && is_active_sidebar($selected_sidebar)) {
    $page_column_class = 'col-lg-8';
} else {
    $page_column_class = 'col-lg-12';
}


if (array_key_exists('enable_banner', $common_meta)) {
    $page_banner = $common_meta['enable_banner'];
} else {
    $page_banner = true;
}

if (array_key_exists('custom_title', $common_meta)) {
    $custom_title = $common_meta['custom_title'];
} else {
    $custom_title = '';
}

if (array_key_exists('banner_text_align_meta', $common_meta) && $common_meta['banner_text_align_meta'] != 'default') {
    $banner_text_align = $common_meta['banner_text_align_meta'];
} else {
    $banner_text_align = innomax_option('banner_default_text_align', 'center');
}

$enable_breadcrumb = innomax_option('enable_breadcrumb', false);
$blog_title_sub = innomax_option('blog_title_sub');
$blog_subtitle_img = innomax_option('blog_subtitle_img');
$blog_image = innomax_option('blog_image');

?>


<?php if ($page_banner == true) : ?>
    <section class="page-title pt-185 page-banner pos-rel bg_img">
        <div class="container">
            <div class="page-title-wrap">
                <div class="row mt-none-30 align-items-end">
                    <div class="col-lg-7 mt-30">
                        <div class="page-title-box text-<?php echo esc_attr($banner_text_align); ?>">
                            <?php if (!empty($blog_title_sub)): ?>
                                <span class="sub-title"><img src="<?php echo esc_url($blog_subtitle_img['url']); ?>"
                                                             alt=""> <?php echo esc_html($blog_title_sub); ?></span>
                            <?php endif; ?>
                            <h2 class="title">
                                <?php
                                if (!empty($custom_title)) {
                                    echo esc_html($custom_title);
                                } else {
                                    the_title();
                                }
                                ?>
                            </h2>
                        </div>
                        <?php if (function_exists('bcn_display') && $enable_breadcrumb == true) : ?>
                            <div class="innomax_breadcrumb">
                                <div class="breadcrumb-container">
                                    <?php bcn_display(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    <?php if (!empty($blog_image['image']['url'])): ?>
                        <div class="col-lg-5 mt-30">
                            <div class="sd-right-img pos-rel">
                                <img src="<?php echo esc_url($blog_image['image']['url']); ?>" alt="">
                                <div class="sd-arrow-shape style-2">
                                    <img class="xbzoominzoomup"
                                         src="<?php echo esc_url($blog_image['shape']['url']); ?>" alt="">
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </section>
<?php endif; ?>

    <div id="primary" class="content-area page-content-area pt-120 pb-130 layout-<?php echo esc_attr($page_layout); ?>">
        <div class="container">
            <div class="row">
                <?php if ($page_layout == 'left-sidebar' && is_active_sidebar($selected_sidebar)) : ?>
                    <div class="col-lg-4 ps-lg-5 order-lg-0 order-last">
                        <?php get_sidebar(); ?>
                    </div>
                <?php endif ?>

                <div class="<?php echo esc_attr($page_column_class); ?>">
                    <?php
                    while (have_posts()) :
                        the_post();

                        get_template_part('template-parts/content', 'page');

                        // If comments are open or we have at least one comment, load up the comment template.
                        if (comments_open() || get_comments_number()) :
                            comments_template();
                        endif;

                    endwhile; // End of the loop.
                    ?>
                </div>

                <?php if ($page_layout == 'right-sidebar' && is_active_sidebar($selected_sidebar)) : ?>
                    <div class="col-lg-4 ps-lg-5 order-lg-0 order-last">
                        <?php get_sidebar(); ?>
                    </div>
                <?php endif ?>
            </div>
        </div>
    </div><!-- #primary -->

<?php get_footer();